﻿/*
	SPDX-License-Identifier: MIT
	Copyright © 2023-2025 Amebis
*/

#include "pch.hpp"

using namespace std;
#ifdef _WIN32
using namespace Microsoft::VisualStudio::CppUnitTestFramework;
#endif

namespace UnitTests
{
	void string::strncpy()
	{
		stdex::utf32_t tmp[0x100];
		stdex::strncpy(tmp, u"This is a 🐔Test🐮.");
		tmp[_countof(tmp) - 1] = 0;
		Assert::IsTrue(stdex::strcmp(U"This is a 🐔Test🐮.", tmp) == 0);
	}

	void string::sprintf()
	{
		stdex::locale locale(stdex::create_locale(LC_ALL, "en_US.UTF-8"));

		Assert::AreEqual(L"This is a test.", stdex::sprintf(L"This is %ls.", locale, L"a test").c_str());
		Assert::IsTrue(stdex::sprintf(L"This is %ls.", locale, L"a test").size() == 15);
		Assert::AreEqual("This is a test.", stdex::sprintf("This is %s.", locale, "a test").c_str());
		Assert::IsTrue(stdex::sprintf("This is %s.", locale, "a test").size() == 15);

		Assert::AreEqual(L"This is a 🐔Test🐮.", stdex::sprintf(L"This is %ls.", locale, L"a 🐔Test🐮").c_str());
		Assert::AreEqual("This is a 🐔Test🐮.", stdex::sprintf("This is %s.", locale, "a 🐔Test🐮").c_str());

		wstring wstr;
		std::string str;
		for (size_t i = 0; i < 200; i++) {
			wstr += L"🐔Test🐮\r\n";
			str += "🐔Test🐮\r\n";
		}
		Assert::AreEqual(wstr.c_str(), stdex::sprintf(L"%ls", locale, wstr.data()).c_str());
		Assert::IsTrue(stdex::sprintf(L"%ls", locale, wstr.data()).size() == wstr.size());
		Assert::AreEqual(str.c_str(), stdex::sprintf("%s", locale, str.data()).c_str());
		Assert::IsTrue(stdex::sprintf("%s", locale, str.data()).size() == str.size());
	}

	void string::snprintf()
	{
		stdex::locale locale(stdex::create_locale(LC_ALL, "en_US.UTF-8"));

		{
			wchar_t buf[0x100];
			Assert::IsTrue(stdex::snprintf(buf, _countof(buf), L"This is %ls.", locale, L"a test") == 15);
			Assert::AreEqual(L"This is a test.", buf);
		}
		{
			char buf[0x100];
			Assert::IsTrue(stdex::snprintf(buf, _countof(buf), "This is %s.", locale, "a test") == 15);
			Assert::AreEqual("This is a test.", buf);
		}

		{
			wchar_t buf[8];
			size_t n = stdex::snprintf(buf, _countof(buf), L"This is %ls.", locale, L"a test");
			Assert::IsTrue(n <= _countof(buf));
			Assert::IsTrue(stdex::strncmp(L"This is a test.", buf, n) == 0);
		}
		{
			char buf[8];
			size_t n = stdex::snprintf(buf, _countof(buf), "This is %s.", locale, "a test");
			Assert::IsTrue(n <= _countof(buf));
			Assert::IsTrue(stdex::strncmp("This is a test.", buf, n) == 0);
		}
	}
}
