﻿/*
	SPDX-License-Identifier: MIT
	Copyright © 2023-2025 Amebis
*/

#pragma once

#include "string.hpp"

#ifdef _WIN32
#define __UTF32_(x) U ## x
#else
#define __UTF32_(x) L ## x
#endif
#define _UTF32_(x)  __UTF32_(x)

namespace stdex
{
	/// \cond internal
	struct sgml_unicode_pair {
		char sgml[12];      ///< Entity name (without leading & and trailing ;)
		utf32_t unicode[3]; ///< UTF-32 string representation
	};

	inline const sgml_unicode_pair sgml_unicode[] = {
		{ "AElig", _UTF32_("\u00c6") },
		{ "Aacgr", _UTF32_("\u0386") },
		{ "Aacute", _UTF32_("\u00c1") },
		{ "Aacute", _UTF32_("\u0041\u0301") },
		{ "Abreve", _UTF32_("\u0102") },
		{ "Abreve", _UTF32_("\u0041\u0306") },
		{ "Abring", _UTF32_("\u0041\u032f") },
		{ "Acaron", _UTF32_("\u0041\u030c") },
		{ "Acirc", _UTF32_("\u00c2") },
		{ "Acirc", _UTF32_("\u0041\u0302") },
		{ "Acy", _UTF32_("\u0410") },
		{ "Adot", _UTF32_("\u0041\u0307") },
		{ "Agr", _UTF32_("\u0391") },
		{ "Agrave", _UTF32_("\u00c0") },
		{ "Agrave", _UTF32_("\u0041\u0300") },
		{ "Alpha", _UTF32_("\u0391") },
		{ "Amacr", _UTF32_("\u0100") },
		{ "Amacr", _UTF32_("\u0041\u0304") },
		{ "Aogon", _UTF32_("\u0104") },
		{ "Aring", _UTF32_("\u00c5") },
		{ "Atilde", _UTF32_("\u00c3") },
		{ "Atilde", _UTF32_("\u0041\u0303") },
		{ "Auml", _UTF32_("\u00c4") },
		{ "Auml", _UTF32_("\u0041\u0308") },
		{ "Bacute", _UTF32_("\u0042\u0301") },
		{ "Barwed", _UTF32_("\u2306") },
		{ "Bbreve", _UTF32_("\u0042\u0306") },
		{ "Bbring", _UTF32_("\u0042\u032f") },
		{ "Bcaron", _UTF32_("\u0042\u030c") },
		{ "Bcirc", _UTF32_("\u0042\u0302") },
		{ "Bcy", _UTF32_("\u0411") },
		{ "Bdot", _UTF32_("\u0042\u0307") },
		{ "Beta", _UTF32_("\u0392") },
		{ "Bgr", _UTF32_("\u0392") },
		{ "Bgrave", _UTF32_("\u0042\u0300") },
		{ "Bmacr", _UTF32_("\u0042\u0304") },
		{ "Btilde", _UTF32_("\u0042\u0303") },
		{ "Buml", _UTF32_("\u0042\u0308") },
		{ "CHcy", _UTF32_("\u0427") },
		{ "Cacute", _UTF32_("\u0106") },
		{ "Cacute", _UTF32_("\u0043\u0301") },
		{ "Cap", _UTF32_("\u22d2") },
		{ "Cbreve", _UTF32_("\u0043\u0306") },
		{ "Cbring", _UTF32_("\u0043\u032f") },
		{ "Ccaron", _UTF32_("\u010c") },
		{ "Ccaron", _UTF32_("\u0043\u030c") },
		{ "Ccedil", _UTF32_("\u00c7") },
		{ "Ccirc", _UTF32_("\u0108") },
		{ "Ccirc", _UTF32_("\u0043\u0302") },
		{ "Cdot", _UTF32_("\u010a") },
		{ "Cdot", _UTF32_("\u0043\u0307") },
		{ "Cgrave", _UTF32_("\u0043\u0300") },
		{ "Chi", _UTF32_("\u03a7") },
		{ "Cmacr", _UTF32_("\u0043\u0304") },
		{ "Ctilde", _UTF32_("\u0043\u0303") },
		{ "Cuml", _UTF32_("\u0043\u0308") },
		{ "Cup", _UTF32_("\u22d3") },
		{ "DJcy", _UTF32_("\u0402") },
		{ "DScy", _UTF32_("\u0405") },
		{ "DZcy", _UTF32_("\u040f") },
		{ "Dacute", _UTF32_("\u0044\u0301") },
		{ "Dagger", _UTF32_("\u2021") },
		{ "Dbreve", _UTF32_("\u0044\u0306") },
		{ "Dbring", _UTF32_("\u0044\u032f") },
		{ "Dcaron", _UTF32_("\u010e") },
		{ "Dcaron", _UTF32_("\u0044\u030c") },
		{ "Dcirc", _UTF32_("\u0044\u0302") },
		{ "Dcy", _UTF32_("\u0414") },
		{ "Ddot", _UTF32_("\u0044\u0307") },
		{ "Delta", _UTF32_("\u0394") },
		{ "Dgr", _UTF32_("\u0394") },
		{ "Dgrave", _UTF32_("\u0044\u0300") },
		{ "Dmacr", _UTF32_("\u0044\u0304") },
		{ "Dot", _UTF32_("\u00a8") },
		{ "DotDot", _UTF32_("\u20dc") },
		{ "Dstrok", _UTF32_("\u0110") },
		{ "Dtilde", _UTF32_("\u0044\u0303") },
		{ "Duml", _UTF32_("\u0044\u0308") },
		{ "EEacgr", _UTF32_("\u0389") },
		{ "EEgr", _UTF32_("\u0397") },
		{ "ENG", _UTF32_("\u014a") },
		{ "ETH", _UTF32_("\u00d0") },
		{ "Eacgr", _UTF32_("\u0388") },
		{ "Eacute", _UTF32_("\u00c9") },
		{ "Eacute", _UTF32_("\u0045\u0301") },
		{ "Ebreve", _UTF32_("\u0045\u0306") },
		{ "Ebring", _UTF32_("\u0045\u032f") },
		{ "Ecaron", _UTF32_("\u011a") },
		{ "Ecaron", _UTF32_("\u0045\u030c") },
		{ "Ecirc", _UTF32_("\u00ca") },
		{ "Ecirc", _UTF32_("\u0045\u0302") },
		{ "Ecy", _UTF32_("\u042d") },
		{ "Edot", _UTF32_("\u0116") },
		{ "Edot", _UTF32_("\u0045\u0307") },
		{ "Edotb", _UTF32_("\u1eb8") },
		{ "Egr", _UTF32_("\u0395") },
		{ "Egrave", _UTF32_("\u00c8") },
		{ "Egrave", _UTF32_("\u0045\u0300") },
		{ "Emacr", _UTF32_("\u0112") },
		{ "Emacr", _UTF32_("\u0045\u0304") },
		{ "Eogon", _UTF32_("\u0118") },
		{ "Epsilon", _UTF32_("\u0395") },
		{ "Eta", _UTF32_("\u0397") },
		{ "Etilde", _UTF32_("\u0045\u0303") },
		{ "Euml", _UTF32_("\u00cb") },
		{ "Euml", _UTF32_("\u0045\u0308") },
		{ "Facute", _UTF32_("\u0046\u0301") },
		{ "Fbreve", _UTF32_("\u0046\u0306") },
		{ "Fbring", _UTF32_("\u0046\u032f") },
		{ "Fcaron", _UTF32_("\u0046\u030c") },
		{ "Fcirc", _UTF32_("\u0046\u0302") },
		{ "Fcy", _UTF32_("\u0424") },
		{ "Fdot", _UTF32_("\u0046\u0307") },
		{ "Fgrave", _UTF32_("\u0046\u0300") },
		{ "Fmacr", _UTF32_("\u0046\u0304") },
		{ "Ftilde", _UTF32_("\u0046\u0303") },
		{ "Fuml", _UTF32_("\u0046\u0308") },
		{ "GJcy", _UTF32_("\u0403") },
		{ "Gacute", _UTF32_("\u0047\u0301") },
		{ "Gamma", _UTF32_("\u0393") },
		{ "Gbreve", _UTF32_("\u011e") },
		{ "Gbreve", _UTF32_("\u0047\u0306") },
		{ "Gbring", _UTF32_("\u0047\u032f") },
		{ "Gcaron", _UTF32_("\u0047\u030c") },
		{ "Gcedil", _UTF32_("\u0122") },
		{ "Gcirc", _UTF32_("\u011c") },
		{ "Gcirc", _UTF32_("\u0047\u0302") },
		{ "Gcy", _UTF32_("\u0413") },
		{ "Gdot", _UTF32_("\u0120") },
		{ "Gdot", _UTF32_("\u0047\u0307") },
		{ "Gg", _UTF32_("\u22d9") },
		{ "Ggr", _UTF32_("\u0393") },
		{ "Ggrave", _UTF32_("\u0047\u0300") },
		{ "Gmacr", _UTF32_("\u0047\u0304") },
		{ "Gt", _UTF32_("\u226b") },
		{ "Gtilde", _UTF32_("\u0047\u0303") },
		{ "Guml", _UTF32_("\u0047\u0308") },
		{ "HARDcy", _UTF32_("\u042a") },
		{ "Hacute", _UTF32_("\u0048\u0301") },
		{ "Hbreve", _UTF32_("\u0048\u0306") },
		{ "Hbring", _UTF32_("\u0048\u032f") },
		{ "Hcaron", _UTF32_("\u0048\u030c") },
		{ "Hcirc", _UTF32_("\u0124") },
		{ "Hcirc", _UTF32_("\u0048\u0302") },
		{ "Hdot", _UTF32_("\u0048\u0307") },
		{ "Hgrave", _UTF32_("\u0048\u0300") },
		{ "Hmacr", _UTF32_("\u0048\u0304") },
		{ "Hstrok", _UTF32_("\u0126") },
		{ "Htilde", _UTF32_("\u0048\u0303") },
		{ "Huml", _UTF32_("\u0048\u0308") },
		{ "IEcy", _UTF32_("\u0415") },
		{ "IJlig", _UTF32_("\u0132") },
		{ "IOcy", _UTF32_("\u0401") },
		{ "Iacgr", _UTF32_("\u038a") },
		{ "Iacute", _UTF32_("\u00cd") },
		{ "Iacute", _UTF32_("\u0049\u0301") },
		{ "Ibreve", _UTF32_("\u0049\u0306") },
		{ "Ibring", _UTF32_("\u0049\u032f") },
		{ "Icaron", _UTF32_("\u0049\u030c") },
		{ "Icirc", _UTF32_("\u00ce") },
		{ "Icirc", _UTF32_("\u0049\u0302") },
		{ "Icy", _UTF32_("\u0418") },
		{ "Idigr", _UTF32_("\u03aa") },
		{ "Idot", _UTF32_("\u0130") },
		{ "Idot", _UTF32_("\u0049\u0307") },
		{ "Igr", _UTF32_("\u0399") },
		{ "Igrave", _UTF32_("\u00cc") },
		{ "Igrave", _UTF32_("\u0049\u0300") },
		{ "Imacr", _UTF32_("\u012a") },
		{ "Imacr", _UTF32_("\u0049\u0304") },
		{ "Iogon", _UTF32_("\u012e") },
		{ "Iota", _UTF32_("\u0399") },
		{ "Itilde", _UTF32_("\u0128") },
		{ "Itilde", _UTF32_("\u0049\u0303") },
		{ "Iukcy", _UTF32_("\u0406") },
		{ "Iuml", _UTF32_("\u00cf") },
		{ "Iuml", _UTF32_("\u0049\u0308") },
		{ "Jacute", _UTF32_("\u004a\u0301") },
		{ "Jbreve", _UTF32_("\u004a\u0306") },
		{ "Jbring", _UTF32_("\u004a\u032f") },
		{ "Jcaron", _UTF32_("\u004a\u030c") },
		{ "Jcirc", _UTF32_("\u0134") },
		{ "Jcirc", _UTF32_("\u004a\u0302") },
		{ "Jcy", _UTF32_("\u0419") },
		{ "Jdot", _UTF32_("\u004a\u0307") },
		{ "Jgrave", _UTF32_("\u004a\u0300") },
		{ "Jmacr", _UTF32_("\u004a\u0304") },
		{ "Jsercy", _UTF32_("\u0408") },
		{ "Jtilde", _UTF32_("\u004a\u0303") },
		{ "Jukcy", _UTF32_("\u0404") },
		{ "Juml", _UTF32_("\u004a\u0308") },
		{ "KHcy", _UTF32_("\u0425") },
		{ "KHgr", _UTF32_("\u03a7") },
		{ "KJcy", _UTF32_("\u040c") },
		{ "Kacute", _UTF32_("\u004b\u0301") },
		{ "Kappa", _UTF32_("\u039a") },
		{ "Kbreve", _UTF32_("\u004b\u0306") },
		{ "Kbring", _UTF32_("\u004b\u032f") },
		{ "Kcaron", _UTF32_("\u004b\u030c") },
		{ "Kcedil", _UTF32_("\u0136") },
		{ "Kcirc", _UTF32_("\u004b\u0302") },
		{ "Kcy", _UTF32_("\u041a") },
		{ "Kdot", _UTF32_("\u004b\u0307") },
		{ "Kgr", _UTF32_("\u039a") },
		{ "Kgrave", _UTF32_("\u004b\u0300") },
		{ "Kmacr", _UTF32_("\u004b\u0304") },
		{ "Ktilde", _UTF32_("\u004b\u0303") },
		{ "Kuml", _UTF32_("\u004b\u0308") },
		{ "LJcy", _UTF32_("\u0409") },
		{ "Lacute", _UTF32_("\u0139") },
		{ "Lacute", _UTF32_("\u004c\u0301") },
		{ "Lambda", _UTF32_("\u039b") },
		{ "Larr", _UTF32_("\u219e") },
		{ "Lbreve", _UTF32_("\u004c\u0306") },
		{ "Lbring", _UTF32_("\u004c\u032f") },
		{ "Lcaron", _UTF32_("\u013d") },
		{ "Lcaron", _UTF32_("\u004c\u030c") },
		{ "Lcedil", _UTF32_("\u013b") },
		{ "Lcirc", _UTF32_("\u004c\u0302") },
		{ "Lcy", _UTF32_("\u041b") },
		{ "Ldot", _UTF32_("\u004c\u0307") },
		{ "Lgr", _UTF32_("\u039b") },
		{ "Lgrave", _UTF32_("\u004c\u0300") },
		{ "Ll", _UTF32_("\u22d8") },
		{ "Lmacr", _UTF32_("\u004c\u0304") },
		{ "Lmidot", _UTF32_("\u013f") },
		{ "Lstrok", _UTF32_("\u0141") },
		{ "Lt", _UTF32_("\u226a") },
		{ "Ltilde", _UTF32_("\u004c\u0303") },
		{ "Luml", _UTF32_("\u004c\u0308") },
		{ "Macute", _UTF32_("\u004d\u0301") },
		{ "Mbreve", _UTF32_("\u004d\u0306") },
		{ "Mbring", _UTF32_("\u004d\u032f") },
		{ "Mcaron", _UTF32_("\u004d\u030c") },
		{ "Mcirc", _UTF32_("\u004d\u0302") },
		{ "Mcy", _UTF32_("\u041c") },
		{ "Mdot", _UTF32_("\u004d\u0307") },
		{ "Mgr", _UTF32_("\u039c") },
		{ "Mgrave", _UTF32_("\u004d\u0300") },
		{ "Mmacr", _UTF32_("\u004d\u0304") },
		{ "Mtilde", _UTF32_("\u004d\u0303") },
		{ "Mu", _UTF32_("\u039c") },
		{ "Muml", _UTF32_("\u004d\u0308") },
		{ "NJcy", _UTF32_("\u040a") },
		{ "Nacute", _UTF32_("\u0143") },
		{ "Nacute", _UTF32_("\u004e\u0301") },
		{ "Nbreve", _UTF32_("\u004e\u0306") },
		{ "Nbring", _UTF32_("\u004e\u032f") },
		{ "Ncaron", _UTF32_("\u0147") },
		{ "Ncaron", _UTF32_("\u004e\u030c") },
		{ "Ncedil", _UTF32_("\u0145") },
		{ "Ncirc", _UTF32_("\u004e\u0302") },
		{ "Ncy", _UTF32_("\u041d") },
		{ "Ndot", _UTF32_("\u004e\u0307") },
		{ "Ngr", _UTF32_("\u039d") },
		{ "Ngrave", _UTF32_("\u004e\u0300") },
		{ "Nmacr", _UTF32_("\u004e\u0304") },
		{ "Ntilde", _UTF32_("\u00d1") },
		{ "Ntilde", _UTF32_("\u004e\u0303") },
		{ "Nu", _UTF32_("\u039d") },
		{ "Numl", _UTF32_("\u004e\u0308") },
		{ "OElig", _UTF32_("\u0152") },
		{ "OHacgr", _UTF32_("\u038f") },
		{ "OHgr", _UTF32_("\u03a9") },
		{ "Oacgr", _UTF32_("\u038c") },
		{ "Oacute", _UTF32_("\u00d3") },
		{ "Oacute", _UTF32_("\u004f\u0301") },
		{ "Obreve", _UTF32_("\u004f\u0306") },
		{ "Obring", _UTF32_("\u004f\u032f") },
		{ "Ocaron", _UTF32_("\u01d1") },
		{ "Ocaron", _UTF32_("\u004f\u030c") },
		{ "Ocirc", _UTF32_("\u00d4") },
		{ "Ocirc", _UTF32_("\u004f\u0302") },
		{ "Ocy", _UTF32_("\u041e") },
		{ "Odblac", _UTF32_("\u0150") },
		{ "Odot", _UTF32_("\u004f\u0307") },
		{ "Odotb", _UTF32_("\u1ecc") },
		{ "Ogr", _UTF32_("\u039f") },
		{ "Ograve", _UTF32_("\u00d2") },
		{ "Ograve", _UTF32_("\u004f\u0300") },
		{ "Omacr", _UTF32_("\u014c") },
		{ "Omacr", _UTF32_("\u004f\u0304") },
		{ "Omega", _UTF32_("\u03a9") },
		{ "Omicron", _UTF32_("\u039f") },
		{ "Oslash", _UTF32_("\u00d8") },
		{ "Otilde", _UTF32_("\u00d5") },
		{ "Otilde", _UTF32_("\u004f\u0303") },
		{ "Ouml", _UTF32_("\u00d6") },
		{ "Ouml", _UTF32_("\u004f\u0308") },
		{ "PHgr", _UTF32_("\u03a6") },
		{ "PSgr", _UTF32_("\u03a8") },
		{ "Pacute", _UTF32_("\u0050\u0301") },
		{ "Pbreve", _UTF32_("\u0050\u0306") },
		{ "Pbring", _UTF32_("\u0050\u032f") },
		{ "Pcaron", _UTF32_("\u0050\u030c") },
		{ "Pcirc", _UTF32_("\u0050\u0302") },
		{ "Pcy", _UTF32_("\u041f") },
		{ "Pdot", _UTF32_("\u0050\u0307") },
		{ "Pgr", _UTF32_("\u03a0") },
		{ "Pgrave", _UTF32_("\u0050\u0300") },
		{ "Phi", _UTF32_("\u03a6") },
		{ "Pi", _UTF32_("\u03a0") },
		{ "Pmacr", _UTF32_("\u0050\u0304") },
		{ "Prime", _UTF32_("\u2033") },
		{ "Psi", _UTF32_("\u03a8") },
		{ "Ptilde", _UTF32_("\u0050\u0303") },
		{ "Puml", _UTF32_("\u0050\u0308") },
		{ "Qacute", _UTF32_("\u0051\u0301") },
		{ "Qbreve", _UTF32_("\u0051\u0306") },
		{ "Qbring", _UTF32_("\u0051\u032f") },
		{ "Qcaron", _UTF32_("\u0051\u030c") },
		{ "Qcirc", _UTF32_("\u0051\u0302") },
		{ "Qdot", _UTF32_("\u0051\u0307") },
		{ "Qgrave", _UTF32_("\u0051\u0300") },
		{ "Qmacr", _UTF32_("\u0051\u0304") },
		{ "Qtilde", _UTF32_("\u0051\u0303") },
		{ "Quml", _UTF32_("\u0051\u0308") },
		{ "Racute", _UTF32_("\u0154") },
		{ "Racute", _UTF32_("\u0052\u0301") },
		{ "Rarr", _UTF32_("\u21a0") },
		{ "Rbreve", _UTF32_("\u0052\u0306") },
		{ "Rbring", _UTF32_("\u0052\u032f") },
		{ "Rcaron", _UTF32_("\u0158") },
		{ "Rcaron", _UTF32_("\u0052\u030c") },
		{ "Rcedil", _UTF32_("\u0156") },
		{ "Rcirc", _UTF32_("\u0052\u0302") },
		{ "Rcy", _UTF32_("\u0420") },
		{ "Rdot", _UTF32_("\u0052\u0307") },
		{ "Rgr", _UTF32_("\u03a1") },
		{ "Rgrave", _UTF32_("\u0052\u0300") },
		{ "Rho", _UTF32_("\u03a1") },
		{ "Rmacr", _UTF32_("\u0052\u0304") },
		{ "Rtilde", _UTF32_("\u0052\u0303") },
		{ "Ruml", _UTF32_("\u0052\u0308") },
		{ "SHCHcy", _UTF32_("\u0429") },
		{ "SHcy", _UTF32_("\u0428") },
		{ "SOFTcy", _UTF32_("\u042c") },
		{ "Sacute", _UTF32_("\u015a") },
		{ "Sacute", _UTF32_("\u0053\u0301") },
		{ "Sbreve", _UTF32_("\u0053\u0306") },
		{ "Sbring", _UTF32_("\u0053\u032f") },
		{ "Scaron", _UTF32_("\u0160") },
		{ "Scaron", _UTF32_("\u0053\u030c") },
		{ "Scedil", _UTF32_("\u015e") },
		{ "Scirc", _UTF32_("\u015c") },
		{ "Scirc", _UTF32_("\u0053\u0302") },
		{ "Scy", _UTF32_("\u0421") },
		{ "Sdot", _UTF32_("\u0053\u0307") },
		{ "Sgr", _UTF32_("\u03a3") },
		{ "Sgrave", _UTF32_("\u0053\u0300") },
		{ "Sigma", _UTF32_("\u03a3") },
		{ "Smacr", _UTF32_("\u0053\u0304") },
		{ "Stilde", _UTF32_("\u0053\u0303") },
		{ "Sub", _UTF32_("\u22d0") },
		{ "Suml", _UTF32_("\u0053\u0308") },
		{ "Sup", _UTF32_("\u22d1") },
		{ "THORN", _UTF32_("\u00de") },
		{ "THgr", _UTF32_("\u0398") },
		{ "TSHcy", _UTF32_("\u040b") },
		{ "TScy", _UTF32_("\u0426") },
		{ "Tacute", _UTF32_("\u0054\u0301") },
		{ "Tau", _UTF32_("\u03a4") },
		{ "Tbreve", _UTF32_("\u0054\u0306") },
		{ "Tbring", _UTF32_("\u0054\u032f") },
		{ "Tcaron", _UTF32_("\u0164") },
		{ "Tcaron", _UTF32_("\u0054\u030c") },
		{ "Tcedil", _UTF32_("\u0162") },
		{ "Tcirc", _UTF32_("\u0054\u0302") },
		{ "Tcy", _UTF32_("\u0422") },
		{ "Tdot", _UTF32_("\u0054\u0307") },
		{ "Tgr", _UTF32_("\u03a4") },
		{ "Tgrave", _UTF32_("\u0054\u0300") },
		{ "Theta", _UTF32_("\u0398") },
		{ "Tmacr", _UTF32_("\u0054\u0304") },
		{ "Tstrok", _UTF32_("\u0166") },
		{ "Ttilde", _UTF32_("\u0054\u0303") },
		{ "Tuml", _UTF32_("\u0054\u0308") },
		{ "Uacgr", _UTF32_("\u038e") },
		{ "Uacute", _UTF32_("\u00da") },
		{ "Uacute", _UTF32_("\u0055\u0301") },
		{ "Ubrcy", _UTF32_("\u040e") },
		{ "Ubreve", _UTF32_("\u016c") },
		{ "Ubreve", _UTF32_("\u0055\u0306") },
		{ "Ubring", _UTF32_("\u0055\u032f") },
		{ "Ucaron", _UTF32_("\u0055\u030c") },
		{ "Ucirc", _UTF32_("\u00db") },
		{ "Ucirc", _UTF32_("\u0055\u0302") },
		{ "Ucy", _UTF32_("\u0423") },
		{ "Udblac", _UTF32_("\u0170") },
		{ "Udigr", _UTF32_("\u03ab") },
		{ "Udot", _UTF32_("\u0055\u0307") },
		{ "Ugr", _UTF32_("\u03a5") },
		{ "Ugrave", _UTF32_("\u00d9") },
		{ "Ugrave", _UTF32_("\u0055\u0300") },
		{ "Umacr", _UTF32_("\u016a") },
		{ "Umacr", _UTF32_("\u0055\u0304") },
		{ "Uogon", _UTF32_("\u0172") },
		{ "Upsi", _UTF32_("\u03a5") },
		{ "Upsilon", _UTF32_("\u03a5") },
		{ "Uring", _UTF32_("\u016e") },
		{ "Utilde", _UTF32_("\u0168") },
		{ "Utilde", _UTF32_("\u0055\u0303") },
		{ "Uuml", _UTF32_("\u00dc") },
		{ "Uuml", _UTF32_("\u0055\u0308") },
		{ "Vacute", _UTF32_("\u0056\u0301") },
		{ "Vbreve", _UTF32_("\u0056\u0306") },
		{ "Vbring", _UTF32_("\u0056\u032f") },
		{ "Vcaron", _UTF32_("\u0056\u030c") },
		{ "Vcirc", _UTF32_("\u0056\u0302") },
		{ "Vcy", _UTF32_("\u0412") },
		{ "Vdash", _UTF32_("\u22a9") },
		{ "Vdot", _UTF32_("\u0056\u0307") },
		{ "Verbar", _UTF32_("\u2016") },
		{ "Vgrave", _UTF32_("\u0056\u0300") },
		{ "Vmacr", _UTF32_("\u0056\u0304") },
		{ "Vtilde", _UTF32_("\u0056\u0303") },
		{ "Vuml", _UTF32_("\u0056\u0308") },
		{ "Vvdash", _UTF32_("\u22aa") },
		{ "Wacute", _UTF32_("\u0057\u0301") },
		{ "Wbreve", _UTF32_("\u0057\u0306") },
		{ "Wbring", _UTF32_("\u0057\u032f") },
		{ "Wcaron", _UTF32_("\u0057\u030c") },
		{ "Wcirc", _UTF32_("\u0174") },
		{ "Wcirc", _UTF32_("\u0057\u0302") },
		{ "Wdot", _UTF32_("\u0057\u0307") },
		{ "Wgrave", _UTF32_("\u0057\u0300") },
		{ "Wmacr", _UTF32_("\u0057\u0304") },
		{ "Wtilde", _UTF32_("\u0057\u0303") },
		{ "Wuml", _UTF32_("\u0057\u0308") },
		{ "Xacute", _UTF32_("\u0058\u0301") },
		{ "Xbreve", _UTF32_("\u0058\u0306") },
		{ "Xbring", _UTF32_("\u0058\u032f") },
		{ "Xcaron", _UTF32_("\u0058\u030c") },
		{ "Xcirc", _UTF32_("\u0058\u0302") },
		{ "Xdot", _UTF32_("\u0058\u0307") },
		{ "Xgr", _UTF32_("\u039e") },
		{ "Xgrave", _UTF32_("\u0058\u0300") },
		{ "Xi", _UTF32_("\u039e") },
		{ "Xmacr", _UTF32_("\u0058\u0304") },
		{ "Xtilde", _UTF32_("\u0058\u0303") },
		{ "Xuml", _UTF32_("\u0058\u0308") },
		{ "YAcy", _UTF32_("\u042f") },
		{ "YIcy", _UTF32_("\u0407") },
		{ "YUcy", _UTF32_("\u042e") },
		{ "Yacute", _UTF32_("\u00dd") },
		{ "Yacute", _UTF32_("\u0059\u0301") },
		{ "Ybreve", _UTF32_("\u0059\u0306") },
		{ "Ybring", _UTF32_("\u0059\u032f") },
		{ "Ycaron", _UTF32_("\u0059\u030c") },
		{ "Ycirc", _UTF32_("\u0176") },
		{ "Ycirc", _UTF32_("\u0059\u0302") },
		{ "Ycy", _UTF32_("\u042b") },
		{ "Ydot", _UTF32_("\u0059\u0307") },
		{ "Ygrave", _UTF32_("\u0059\u0300") },
		{ "Ymacr", _UTF32_("\u0059\u0304") },
		{ "Ytilde", _UTF32_("\u0059\u0303") },
		{ "Yuml", _UTF32_("\u0178") },
		{ "Yuml", _UTF32_("\u0059\u0308") },
		{ "ZHcy", _UTF32_("\u0416") },
		{ "Zacute", _UTF32_("\u0179") },
		{ "Zacute", _UTF32_("\u005a\u0301") },
		{ "Zbreve", _UTF32_("\u005a\u0306") },
		{ "Zbring", _UTF32_("\u005a\u032f") },
		{ "Zcaron", _UTF32_("\u017d") },
		{ "Zcaron", _UTF32_("\u005a\u030c") },
		{ "Zcirc", _UTF32_("\u005a\u0302") },
		{ "Zcy", _UTF32_("\u0417") },
		{ "Zdot", _UTF32_("\u017b") },
		{ "Zdot", _UTF32_("\u005a\u0307") },
		{ "Zeta", _UTF32_("\u0396") },
		{ "Zgr", _UTF32_("\u0396") },
		{ "Zgrave", _UTF32_("\u005a\u0300") },
		{ "Zmacr", _UTF32_("\u005a\u0304") },
		{ "Ztilde", _UTF32_("\u005a\u0303") },
		{ "Zuml", _UTF32_("\u005a\u0308") },
		{ "aacgr", _UTF32_("\u03ac") },
		{ "aacute", _UTF32_("\u00e1") },
		{ "aacute", _UTF32_("\u0061\u0301") },
		{ "abreve", _UTF32_("\u0103") },
		{ "abreve", _UTF32_("\u0061\u0306") },
		{ "abring", _UTF32_("\u0061\u032f") },
		{ "acaron", _UTF32_("\u0061\u030c") },
		{ "acirc", _UTF32_("\u00e2") },
		{ "acirc", _UTF32_("\u0061\u0302") },
		{ "acute", _UTF32_("\u00b4") },
		{ "acy", _UTF32_("\u0430") },
		{ "adot", _UTF32_("\u0061\u0307") },
		{ "aelig", _UTF32_("\u00e6") },
		{ "agr", _UTF32_("\u03b1") },
		{ "agrave", _UTF32_("\u00e0") },
		{ "agrave", _UTF32_("\u0061\u0300") },
		{ "alefsym", _UTF32_("\u2135") },
		{ "aleph", _UTF32_("\u2135") },
		{ "alpha", _UTF32_("\u03b1") },
		{ "amacr", _UTF32_("\u0101") },
		{ "amacr", _UTF32_("\u0061\u0304") },
		{ "amalg", _UTF32_("\u2210") },
		{ "amp", _UTF32_("\u0026") },
		{ "and", _UTF32_("\u2227") },
		{ "ang", _UTF32_("\u2220") },
		{ "ang90", _UTF32_("\u221f") },
		{ "angmsd", _UTF32_("\u2221") },
		{ "angsph", _UTF32_("\u2222") },
		{ "angst", _UTF32_("\u212b") },
		{ "aogon", _UTF32_("\u0105") },
		{ "ap", _UTF32_("\u2248") },
		{ "ape", _UTF32_("\u224a") },
		{ "apos", _UTF32_("\u0027") },
		{ "apos", _UTF32_("\u02bc") },
		{ "aring", _UTF32_("\u00e5") },
		{ "ast", _UTF32_("\u002a") },
		{ "asymp", _UTF32_("\u2248") },
		{ "atilde", _UTF32_("\u00e3") },
		{ "atilde", _UTF32_("\u0061\u0303") },
		{ "auml", _UTF32_("\u00e4") },
		{ "auml", _UTF32_("\u0061\u0308") },
		{ "b.Delta", _UTF32_("\u0394") },
		{ "b.Gamma", _UTF32_("\u0393") },
		{ "b.Lambda", _UTF32_("\u039b") },
		{ "b.Omega", _UTF32_("\u03a9") },
		{ "b.Phi", _UTF32_("\u03a6") },
		{ "b.Pi", _UTF32_("\u03a0") },
		{ "b.Psi", _UTF32_("\u03a8") },
		{ "b.Sigma", _UTF32_("\u03a3") },
		{ "b.Theta", _UTF32_("\u0398") },
		{ "b.Upsi", _UTF32_("\u03a5") },
		{ "b.Xi", _UTF32_("\u039e") },
		{ "b.alpha", _UTF32_("\u03b1") },
		{ "b.beta", _UTF32_("\u03b2") },
		{ "b.chi", _UTF32_("\u03c7") },
		{ "b.delta", _UTF32_("\u03b4") },
		{ "b.epsi", _UTF32_("\u03b5") },
		{ "b.epsis", _UTF32_("\u03b5") },
		{ "b.epsiv", _UTF32_("\u03b5") },
		{ "b.eta", _UTF32_("\u03b7") },
		{ "b.gamma", _UTF32_("\u03b3") },
		{ "b.gammad", _UTF32_("\u03dc") },
		{ "b.iota", _UTF32_("\u03b9") },
		{ "b.kappa", _UTF32_("\u03ba") },
		{ "b.kappav", _UTF32_("\u03f0") },
		{ "b.lambda", _UTF32_("\u03bb") },
		{ "b.mu", _UTF32_("\u03bc") },
		{ "b.nu", _UTF32_("\u03bd") },
		{ "b.omega", _UTF32_("\u03ce") },
		{ "b.phis", _UTF32_("\u03c6") },
		{ "b.phiv", _UTF32_("\u03d5") },
		{ "b.pi", _UTF32_("\u03c0") },
		{ "b.piv", _UTF32_("\u03d6") },
		{ "b.psi", _UTF32_("\u03c8") },
		{ "b.rho", _UTF32_("\u03c1") },
		{ "b.rhov", _UTF32_("\u03f1") },
		{ "b.sigma", _UTF32_("\u03c3") },
		{ "b.sigmav", _UTF32_("\u03c2") },
		{ "b.tau", _UTF32_("\u03c4") },
		{ "b.thetas", _UTF32_("\u03b8") },
		{ "b.thetav", _UTF32_("\u03d1") },
		{ "b.upsi", _UTF32_("\u03c5") },
		{ "b.xi", _UTF32_("\u03be") },
		{ "b.zeta", _UTF32_("\u03b6") },
		{ "bacute", _UTF32_("\u0062\u0301") },
		{ "barwed", _UTF32_("\u22bc") },
		{ "bbreve", _UTF32_("\u0062\u0306") },
		{ "bbring", _UTF32_("\u0062\u032f") },
		{ "bcaron", _UTF32_("\u0062\u030c") },
		{ "bcirc", _UTF32_("\u0062\u0302") },
		{ "bcong", _UTF32_("\u224c") },
		{ "bcy", _UTF32_("\u0431") },
		{ "bdot", _UTF32_("\u0062\u0307") },
		{ "bdquo", _UTF32_("\u201e") },
		{ "becaus", _UTF32_("\u2235") },
		{ "bepsi", _UTF32_("\u220d") },
		{ "bernou", _UTF32_("\u212c") },
		{ "beta", _UTF32_("\u03b2") },
		{ "beth", _UTF32_("\u2136") },
		{ "bgr", _UTF32_("\u03b2") },
		{ "bgrave", _UTF32_("\u0062\u0300") },
		{ "blank", _UTF32_("\u2423") },
		{ "blk12", _UTF32_("\u2592") },
		{ "blk14", _UTF32_("\u2591") },
		{ "blk34", _UTF32_("\u2593") },
		{ "block", _UTF32_("\u2588") },
		{ "bmacr", _UTF32_("\u0062\u0304") },
		{ "bottom", _UTF32_("\u22a5") },
		{ "bowtie", _UTF32_("\u22c8") },
		{ "boxDL", _UTF32_("\u2557") },
		{ "boxDR", _UTF32_("\u2554") },
		{ "boxDl", _UTF32_("\u2556") },
		{ "boxDr", _UTF32_("\u2553") },
		{ "boxH", _UTF32_("\u2550") },
		{ "boxHD", _UTF32_("\u2566") },
		{ "boxHU", _UTF32_("\u2569") },
		{ "boxHd", _UTF32_("\u2564") },
		{ "boxHu", _UTF32_("\u2567") },
		{ "boxUL", _UTF32_("\u255d") },
		{ "boxUR", _UTF32_("\u255a") },
		{ "boxUl", _UTF32_("\u255c") },
		{ "boxUr", _UTF32_("\u2559") },
		{ "boxV", _UTF32_("\u2551") },
		{ "boxVH", _UTF32_("\u256c") },
		{ "boxVL", _UTF32_("\u2563") },
		{ "boxVR", _UTF32_("\u2560") },
		{ "boxVh", _UTF32_("\u256b") },
		{ "boxVl", _UTF32_("\u2562") },
		{ "boxVr", _UTF32_("\u255f") },
		{ "boxdL", _UTF32_("\u2555") },
		{ "boxdR", _UTF32_("\u2552") },
		{ "boxdl", _UTF32_("\u2510") },
		{ "boxdr", _UTF32_("\u250c") },
		{ "boxh", _UTF32_("\u2500") },
		{ "boxhD", _UTF32_("\u2565") },
		{ "boxhU", _UTF32_("\u2568") },
		{ "boxhd", _UTF32_("\u252c") },
		{ "boxhu", _UTF32_("\u2534") },
		{ "boxuL", _UTF32_("\u255b") },
		{ "boxuR", _UTF32_("\u2558") },
		{ "boxul", _UTF32_("\u2518") },
		{ "boxur", _UTF32_("\u2514") },
		{ "boxv", _UTF32_("\u2502") },
		{ "boxvH", _UTF32_("\u256a") },
		{ "boxvL", _UTF32_("\u2561") },
		{ "boxvR", _UTF32_("\u255e") },
		{ "boxvh", _UTF32_("\u253c") },
		{ "boxvl", _UTF32_("\u2524") },
		{ "boxvr", _UTF32_("\u251c") },
		{ "bprime", _UTF32_("\u2035") },
		{ "breve", _UTF32_("\u02d8") },
		{ "brvbar", _UTF32_("\u00a6") },
		{ "bsim", _UTF32_("\u223d") },
		{ "bsime", _UTF32_("\u22cd") },
		{ "bsol", _UTF32_("\u005c") },
		{ "btilde", _UTF32_("\u0062\u0303") },
		{ "bull", _UTF32_("\u2022") },
		{ "buml", _UTF32_("\u0062\u0308") },
		{ "bump", _UTF32_("\u224e") },
		{ "bumpe", _UTF32_("\u224f") },
		{ "cacute", _UTF32_("\u0107") },
		{ "cacute", _UTF32_("\u0063\u0301") },
		{ "cap", _UTF32_("\u2229") },
		{ "caret", _UTF32_("\u2041") },
		{ "caron", _UTF32_("\u02c7") },
		{ "cbreve", _UTF32_("\u0063\u0306") },
		{ "cbring", _UTF32_("\u0063\u032f") },
		{ "ccaron", _UTF32_("\u010d") },
		{ "ccaron", _UTF32_("\u0063\u030c") },
		{ "ccedil", _UTF32_("\u00e7") },
		{ "ccirc", _UTF32_("\u0109") },
		{ "ccirc", _UTF32_("\u0063\u0302") },
		{ "cdot", _UTF32_("\u010b") },
		{ "cdot", _UTF32_("\u0063\u0307") },
		{ "cedil", _UTF32_("\u00b8") },
		{ "cent", _UTF32_("\u00a2") },
		{ "cgrave", _UTF32_("\u0063\u0300") },
		{ "chcy", _UTF32_("\u0447") },
		{ "check", _UTF32_("\u2713") },
		{ "chi", _UTF32_("\u03c7") },
		{ "cir", _UTF32_("\u25cb") },
		{ "circ", _UTF32_("\u02c6") },
		{ "circlef", _UTF32_("\u25cf") },
		{ "circlefb", _UTF32_("\u25d2") },
		{ "circlefl", _UTF32_("\u25d0") },
		{ "circlefr", _UTF32_("\u25d1") },
		{ "circleft", _UTF32_("\u25d3") },
		{ "cire", _UTF32_("\u2257") },
		{ "clubs", _UTF32_("\u2663") },
		{ "cmacr", _UTF32_("\u0063\u0304") },
		{ "colon", _UTF32_("\u003a") },
		{ "colone", _UTF32_("\u2254") },
		{ "comma", _UTF32_("\u002c") },
		{ "commat", _UTF32_("\u0040") },
		{ "comp", _UTF32_("\u2201") },
		{ "compfn", _UTF32_("\u2218") },
		{ "cong", _UTF32_("\u2245") },
		{ "conint", _UTF32_("\u222e") },
		{ "coprod", _UTF32_("\u2210") },
		{ "copy", _UTF32_("\u00a9") },
		{ "copysr", _UTF32_("\u2117") },
		{ "crarr", _UTF32_("\u21b5") },
		{ "cross", _UTF32_("\u2717") },
		{ "ctilde", _UTF32_("\u0063\u0303") },
		{ "cuepr", _UTF32_("\u22de") },
		{ "cuesc", _UTF32_("\u22df") },
		{ "cularr", _UTF32_("\u21b6") },
		{ "cuml", _UTF32_("\u0063\u0308") },
		{ "cup", _UTF32_("\u222a") },
		{ "cupre", _UTF32_("\u227c") },
		{ "curarr", _UTF32_("\u21b7") },
		{ "curren", _UTF32_("\u00a4") },
		{ "cuvee", _UTF32_("\u22ce") },
		{ "cuwed", _UTF32_("\u22cf") },
		{ "dArr", _UTF32_("\u21d3") },
		{ "dacute", _UTF32_("\u0064\u0301") },
		{ "dagger", _UTF32_("\u2020") },
		{ "daleth", _UTF32_("\u2138") },
		{ "darr", _UTF32_("\u2193") },
		{ "darr2", _UTF32_("\u21ca") },
		{ "dash", _UTF32_("\u2010") },
		{ "dashv", _UTF32_("\u22a3") },
		{ "dblac", _UTF32_("\u02dd") },
		{ "dbreve", _UTF32_("\u0064\u0306") },
		{ "dbring", _UTF32_("\u0064\u032f") },
		{ "dcaron", _UTF32_("\u010f") },
		{ "dcaron", _UTF32_("\u0064\u030c") },
		{ "dcirc", _UTF32_("\u0064\u0302") },
		{ "dcy", _UTF32_("\u0434") },
		{ "ddot", _UTF32_("\u0064\u0307") },
		{ "deg", _UTF32_("\u00b0") },
		{ "delta", _UTF32_("\u03b4") },
		{ "dgr", _UTF32_("\u03b4") },
		{ "dgrave", _UTF32_("\u0064\u0300") },
		{ "dharl", _UTF32_("\u21c3") },
		{ "dharr", _UTF32_("\u21c2") },
		{ "diam", _UTF32_("\u22c4") },
		{ "diamondf", _UTF32_("\u25c6") },
		{ "diams", _UTF32_("\u2666") },
		{ "die", _UTF32_("\u00a8") },
		{ "divide", _UTF32_("\u00f7") },
		{ "divonx", _UTF32_("\u22c7") },
		{ "djcy", _UTF32_("\u0452") },
		{ "dlarr", _UTF32_("\u2199") },
		{ "dlcorn", _UTF32_("\u231e") },
		{ "dlcrop", _UTF32_("\u230d") },
		{ "dmacr", _UTF32_("\u0064\u0304") },
		{ "dollar", _UTF32_("\u0024") },
		{ "dot", _UTF32_("\u02d9") },
		{ "drarr", _UTF32_("\u2198") },
		{ "drcorn", _UTF32_("\u231f") },
		{ "drcrop", _UTF32_("\u230c") },
		{ "dscy", _UTF32_("\u0455") },
		{ "dstrok", _UTF32_("\u0111") },
		{ "dtilde", _UTF32_("\u0064\u0303") },
		{ "dtri", _UTF32_("\u25bf") },
		{ "dtrif", _UTF32_("\u25be") },
		{ "duml", _UTF32_("\u0064\u0308") },
		{ "dzcy", _UTF32_("\u045f") },
		{ "eDot", _UTF32_("\u2251") },
		{ "eacgr", _UTF32_("\u03ad") },
		{ "eacute", _UTF32_("\u00e9") },
		{ "eacute", _UTF32_("\u0065\u0301") },
		{ "ebreve", _UTF32_("\u0065\u0306") },
		{ "ebring", _UTF32_("\u0065\u032f") },
		{ "ecaron", _UTF32_("\u011b") },
		{ "ecaron", _UTF32_("\u0065\u030c") },
		{ "ecir", _UTF32_("\u2256") },
		{ "ecirc", _UTF32_("\u00ea") },
		{ "ecirc", _UTF32_("\u0065\u0302") },
		{ "ecolon", _UTF32_("\u2255") },
		{ "ecy", _UTF32_("\u044d") },
		{ "edot", _UTF32_("\u0117") },
		{ "edot", _UTF32_("\u0065\u0307") },
		{ "edotb", _UTF32_("\u1eb9") },
		{ "eeacgr", _UTF32_("\u03ae") },
		{ "eegr", _UTF32_("\u03b7") },
		{ "efDot", _UTF32_("\u2252") },
		{ "egr", _UTF32_("\u03b5") },
		{ "egrave", _UTF32_("\u00e8") },
		{ "egrave", _UTF32_("\u0065\u0300") },
		{ "egs", _UTF32_("\u22dd") },
		{ "ell", _UTF32_("\u2113") },
		{ "els", _UTF32_("\u22dc") },
		{ "emacr", _UTF32_("\u0113") },
		{ "emacr", _UTF32_("\u0065\u0304") },
		{ "empty", _UTF32_("\u2205") },
		{ "emsp", _UTF32_("\u2003") },
		{ "emsp13", _UTF32_("\u2004") },
		{ "emsp14", _UTF32_("\u2005") },
		{ "eng", _UTF32_("\u014b") },
		{ "ensp", _UTF32_("\u2002") },
		{ "eogon", _UTF32_("\u0119") },
		{ "epsi", _UTF32_("\u03b5") },
		{ "epsilon", _UTF32_("\u03b5") },
		{ "epsis", _UTF32_("\u220a") },
		{ "equals", _UTF32_("\u003d") },
		{ "equiv", _UTF32_("\u2261") },
		{ "erDot", _UTF32_("\u2253") },
		{ "esdot", _UTF32_("\u2250") },
		{ "eta", _UTF32_("\u03b7") },
		{ "eth", _UTF32_("\u00f0") },
		{ "etilde", _UTF32_("\u0065\u0303") },
		{ "euml", _UTF32_("\u00eb") },
		{ "euml", _UTF32_("\u0065\u0308") },
		{ "euro", _UTF32_("\u20ac") },
		{ "excl", _UTF32_("\u0021") },
		{ "exist", _UTF32_("\u2203") },
		{ "facute", _UTF32_("\u0066\u0301") },
		{ "fbreve", _UTF32_("\u0066\u0306") },
		{ "fbring", _UTF32_("\u0066\u032f") },
		{ "fcaron", _UTF32_("\u0066\u030c") },
		{ "fcirc", _UTF32_("\u0066\u0302") },
		{ "fcy", _UTF32_("\u0444") },
		{ "fdot", _UTF32_("\u0066\u0307") },
		{ "female", _UTF32_("\u2640") },
		{ "ffilig", _UTF32_("\ufb03") },
		{ "fflig", _UTF32_("\ufb00") },
		{ "ffllig", _UTF32_("\ufb04") },
		{ "fgrave", _UTF32_("\u0066\u0300") },
		{ "filig", _UTF32_("\ufb01") },
		{ "flat", _UTF32_("\u266d") },
		{ "fllig", _UTF32_("\ufb02") },
		{ "fmacr", _UTF32_("\u0066\u0304") },
		{ "fnof", _UTF32_("\u0192") },
		{ "forall", _UTF32_("\u2200") },
		{ "fork", _UTF32_("\u22d4") },
		{ "frac12", _UTF32_("\u00bd") },
		{ "frac13", _UTF32_("\u2153") },
		{ "frac14", _UTF32_("\u00bc") },
		{ "frac15", _UTF32_("\u2155") },
		{ "frac16", _UTF32_("\u2159") },
		{ "frac18", _UTF32_("\u215b") },
		{ "frac23", _UTF32_("\u2154") },
		{ "frac25", _UTF32_("\u2156") },
		{ "frac34", _UTF32_("\u00be") },
		{ "frac35", _UTF32_("\u2157") },
		{ "frac38", _UTF32_("\u215c") },
		{ "frac45", _UTF32_("\u2158") },
		{ "frac56", _UTF32_("\u215a") },
		{ "frac58", _UTF32_("\u215d") },
		{ "frac78", _UTF32_("\u215e") },
		{ "frasl", _UTF32_("\u2044") },
		{ "frown", _UTF32_("\u2322") },
		{ "ftilde", _UTF32_("\u0066\u0303") },
		{ "fuml", _UTF32_("\u0066\u0308") },
		{ "gE", _UTF32_("\u2267") },
		{ "gacute", _UTF32_("\u01f5") },
		{ "gacute", _UTF32_("\u0067\u0301") },
		{ "gamma", _UTF32_("\u03b3") },
		{ "gammad", _UTF32_("\u03dc") },
		{ "gbreve", _UTF32_("\u011f") },
		{ "gbreve", _UTF32_("\u0067\u0306") },
		{ "gbring", _UTF32_("\u0067\u032f") },
		{ "gcaron", _UTF32_("\u0067\u030c") },
		{ "gcedil", _UTF32_("\u0123") },
		{ "gcirc", _UTF32_("\u011d") },
		{ "gcirc", _UTF32_("\u0067\u0302") },
		{ "gcy", _UTF32_("\u0433") },
		{ "gdot", _UTF32_("\u0121") },
		{ "gdot", _UTF32_("\u0067\u0307") },
		{ "ge", _UTF32_("\u2265") },
		{ "gel", _UTF32_("\u22db") },
		{ "ges", _UTF32_("\u2265") },
		{ "ggr", _UTF32_("\u03b3") },
		{ "ggrave", _UTF32_("\u0067\u0300") },
		{ "gimel", _UTF32_("\u2137") },
		{ "gjcy", _UTF32_("\u0453") },
		{ "gl", _UTF32_("\u2277") },
		{ "gmacr", _UTF32_("\u0067\u0304") },
		{ "gnE", _UTF32_("\u2269") },
		{ "gne", _UTF32_("\u2269") },
		{ "gnsim", _UTF32_("\u22e7") },
		{ "grave", _UTF32_("\u0060") },
		{ "gsdot", _UTF32_("\u22d7") },
		{ "gsim", _UTF32_("\u2273") },
		{ "gt", _UTF32_("\u003e") },
		{ "gtilde", _UTF32_("\u0067\u0303") },
		{ "guml", _UTF32_("\u0067\u0308") },
		{ "gvnE", _UTF32_("\u2269") },
		{ "hArr", _UTF32_("\u21d4") },
		{ "hacute", _UTF32_("\u0068\u0301") },
		{ "hairsp", _UTF32_("\u200a") },
		{ "half", _UTF32_("\u00bd") },
		{ "hamilt", _UTF32_("\u210b") },
		{ "hardcy", _UTF32_("\u044a") },
		{ "harr", _UTF32_("\u2194") },
		{ "harrw", _UTF32_("\u21ad") },
		{ "hbreve", _UTF32_("\u0068\u0306") },
		{ "hbring", _UTF32_("\u0068\u032f") },
		{ "hcaron", _UTF32_("\u0068\u030c") },
		{ "hcirc", _UTF32_("\u0125") },
		{ "hcirc", _UTF32_("\u0068\u0302") },
		{ "hdot", _UTF32_("\u0068\u0307") },
		{ "hearts", _UTF32_("\u2665") },
		{ "hellip", _UTF32_("\u2026") },
		{ "hgrave", _UTF32_("\u0068\u0300") },
		{ "hmacr", _UTF32_("\u0068\u0304") },
		{ "horbar", _UTF32_("\u2015") },
		{ "hstrok", _UTF32_("\u0127") },
		{ "htilde", _UTF32_("\u0068\u0303") },
		{ "huml", _UTF32_("\u0068\u0308") },
		{ "hybull", _UTF32_("\u2043") },
		{ "hyphen", _UTF32_("\u002d") },
		{ "iacgr", _UTF32_("\u03af") },
		{ "iacute", _UTF32_("\u00ed") },
		{ "iacute", _UTF32_("\u0069\u0301") },
		{ "ibreve", _UTF32_("\u0069\u0306") },
		{ "ibring", _UTF32_("\u0069\u032f") },
		{ "icaron", _UTF32_("\u0069\u030c") },
		{ "icirc", _UTF32_("\u00ee") },
		{ "icirc", _UTF32_("\u0069\u0302") },
		{ "icy", _UTF32_("\u0438") },
		{ "idiagr", _UTF32_("\u0390") },
		{ "idigr", _UTF32_("\u03ca") },
		{ "idot", _UTF32_("\u0069\u0307") },
		{ "iecy", _UTF32_("\u0435") },
		{ "iexcl", _UTF32_("\u00a1") },
		{ "iff", _UTF32_("\u21d4") },
		{ "igr", _UTF32_("\u03b9") },
		{ "igrave", _UTF32_("\u00ec") },
		{ "igrave", _UTF32_("\u0069\u0300") },
		{ "ijlig", _UTF32_("\u0133") },
		{ "imacr", _UTF32_("\u012b") },
		{ "imacr", _UTF32_("\u0069\u0304") },
		{ "image", _UTF32_("\u2111") },
		{ "incare", _UTF32_("\u2105") },
		{ "infin", _UTF32_("\u221e") },
		{ "inodot", _UTF32_("\u0131") },
		{ "inodot", _UTF32_("\u0131") },
		{ "int", _UTF32_("\u222b") },
		{ "intcal", _UTF32_("\u22ba") },
		{ "iocy", _UTF32_("\u0451") },
		{ "iogon", _UTF32_("\u012f") },
		{ "iota", _UTF32_("\u03b9") },
		{ "iquest", _UTF32_("\u00bf") },
		{ "isin", _UTF32_("\u2208") },
		{ "itilde", _UTF32_("\u0129") },
		{ "itilde", _UTF32_("\u0069\u0303") },
		{ "iukcy", _UTF32_("\u0456") },
		{ "iuml", _UTF32_("\u00ef") },
		{ "iuml", _UTF32_("\u0069\u0308") },
		{ "jacute", _UTF32_("\u006a\u0301") },
		{ "jbreve", _UTF32_("\u006a\u0306") },
		{ "jbring", _UTF32_("\u006a\u032f") },
		{ "jcaron", _UTF32_("\u006a\u030c") },
		{ "jcirc", _UTF32_("\u0135") },
		{ "jcirc", _UTF32_("\u006a\u0302") },
		{ "jcy", _UTF32_("\u0439") },
		{ "jdot", _UTF32_("\u006a\u0307") },
		{ "jgrave", _UTF32_("\u006a\u0300") },
		{ "jmacr", _UTF32_("\u006a\u0304") },
		{ "jsercy", _UTF32_("\u0458") },
		{ "jtilde", _UTF32_("\u006a\u0303") },
		{ "jukcy", _UTF32_("\u0454") },
		{ "juml", _UTF32_("\u006a\u0308") },
		{ "kacute", _UTF32_("\u006b\u0301") },
		{ "kappa", _UTF32_("\u03ba") },
		{ "kappav", _UTF32_("\u03f0") },
		{ "kbreve", _UTF32_("\u006b\u0306") },
		{ "kbring", _UTF32_("\u006b\u032f") },
		{ "kcaron", _UTF32_("\u006b\u030c") },
		{ "kcedil", _UTF32_("\u0137") },
		{ "kcirc", _UTF32_("\u006b\u0302") },
		{ "kcy", _UTF32_("\u043a") },
		{ "kdot", _UTF32_("\u006b\u0307") },
		{ "kgr", _UTF32_("\u03ba") },
		{ "kgrave", _UTF32_("\u006b\u0300") },
		{ "kgreen", _UTF32_("\u0138") },
		{ "khcy", _UTF32_("\u0445") },
		{ "khgr", _UTF32_("\u03c7") },
		{ "kjcy", _UTF32_("\u045c") },
		{ "kmacr", _UTF32_("\u006b\u0304") },
		{ "ktilde", _UTF32_("\u006b\u0303") },
		{ "kuml", _UTF32_("\u006b\u0308") },
		{ "lAarr", _UTF32_("\u21da") },
		{ "lArr", _UTF32_("\u21d0") },
		{ "lE", _UTF32_("\u2266") },
		{ "lacute", _UTF32_("\u013a") },
		{ "lacute", _UTF32_("\u006c\u0301") },
		{ "lagran", _UTF32_("\u2112") },
		{ "lambda", _UTF32_("\u03bb") },
		{ "lang", _UTF32_("\u2329") },
		{ "laquo", _UTF32_("\u00ab") },
		{ "larr", _UTF32_("\u2190") },
		{ "larr2", _UTF32_("\u21c7") },
		{ "larrhk", _UTF32_("\u21a9") },
		{ "larrlp", _UTF32_("\u21ab") },
		{ "larrtl", _UTF32_("\u21a2") },
		{ "lbreve", _UTF32_("\u006c\u0306") },
		{ "lbring", _UTF32_("\u006c\u032f") },
		{ "lcaron", _UTF32_("\u013e") },
		{ "lcaron", _UTF32_("\u006c\u030c") },
		{ "lcedil", _UTF32_("\u013c") },
		{ "lceil", _UTF32_("\u2308") },
		{ "lcirc", _UTF32_("\u006c\u0302") },
		{ "lcub", _UTF32_("\u007b") },
		{ "lcy", _UTF32_("\u043b") },
		{ "ldot", _UTF32_("\u22d6") },
		{ "ldot", _UTF32_("\u006c\u0307") },
		{ "ldquo", _UTF32_("\u201c") },
		{ "ldquor", _UTF32_("\u201e") },
		{ "le", _UTF32_("\u2264") },
		{ "leg", _UTF32_("\u22da") },
		{ "les", _UTF32_("\u2264") },
		{ "lfloor", _UTF32_("\u230a") },
		{ "lg", _UTF32_("\u2276") },
		{ "lgr", _UTF32_("\u03bb") },
		{ "lgrave", _UTF32_("\u006c\u0300") },
		{ "lhard", _UTF32_("\u21bd") },
		{ "lharu", _UTF32_("\u21bc") },
		{ "lhblk", _UTF32_("\u2584") },
		{ "ljcy", _UTF32_("\u0459") },
		{ "lmacr", _UTF32_("\u006c\u0304") },
		{ "lmidot", _UTF32_("\u0140") },
		{ "lnE", _UTF32_("\u2268") },
		{ "lne", _UTF32_("\u2268") },
		{ "lnsim", _UTF32_("\u22e6") },
		{ "lowast", _UTF32_("\u2217") },
		{ "lowbar", _UTF32_("\u005f") },
		{ "loz", _UTF32_("\u25ca") },
		{ "loz", _UTF32_("\u2727") },
		{ "lozf", _UTF32_("\u2726") },
		{ "lpar", _UTF32_("\u0028") },
		{ "lrarr2", _UTF32_("\u21c6") },
		{ "lrhar2", _UTF32_("\u21cb") },
		{ "lrm", _UTF32_("\u200e") },
		{ "lsaquo", _UTF32_("\u2039") },
		{ "lsh", _UTF32_("\u21b0") },
		{ "lsim", _UTF32_("\u2272") },
		{ "lsqb", _UTF32_("\u005b") },
		{ "lsquo", _UTF32_("\u2018") },
		{ "lsquor", _UTF32_("\u201a") },
		{ "lstrok", _UTF32_("\u0142") },
		{ "lt", _UTF32_("\u003c") },
		{ "lthree", _UTF32_("\u22cb") },
		{ "ltilde", _UTF32_("\u006c\u0303") },
		{ "ltimes", _UTF32_("\u22c9") },
		{ "ltri", _UTF32_("\u25c3") },
		{ "ltrie", _UTF32_("\u22b4") },
		{ "ltrif", _UTF32_("\u25c2") },
		{ "luml", _UTF32_("\u006c\u0308") },
		{ "lvnE", _UTF32_("\u2268") },
		{ "macr", _UTF32_("\u00af") },
		{ "macute", _UTF32_("\u006d\u0301") },
		{ "male", _UTF32_("\u2642") },
		{ "malt", _UTF32_("\u2720") },
		{ "map", _UTF32_("\u21a6") },
		{ "marker", _UTF32_("\u25ae") },
		{ "mbreve", _UTF32_("\u006d\u0306") },
		{ "mbring", _UTF32_("\u006d\u032f") },
		{ "mcaron", _UTF32_("\u006d\u030c") },
		{ "mcirc", _UTF32_("\u006d\u0302") },
		{ "mcy", _UTF32_("\u043c") },
		{ "mdash", _UTF32_("\u2014") },
		{ "mdot", _UTF32_("\u006d\u0307") },
		{ "mgr", _UTF32_("\u03bc") },
		{ "mgrave", _UTF32_("\u006d\u0300") },
		{ "micro", _UTF32_("\u00b5") },
		{ "mid", _UTF32_("\u2223") },
		{ "middot", _UTF32_("\u00b7") },
		{ "minus", _UTF32_("\u2212") },
		{ "minusb", _UTF32_("\u229f") },
		{ "mldr", _UTF32_("\u2026") },
		{ "mmacr", _UTF32_("\u006d\u0304") },
		{ "mnplus", _UTF32_("\u2213") },
		{ "models", _UTF32_("\u22a7") },
		{ "mtilde", _UTF32_("\u006d\u0303") },
		{ "mu", _UTF32_("\u03bc") },
		{ "mumap", _UTF32_("\u22b8") },
		{ "muml", _UTF32_("\u006d\u0308") },
		{ "nVDash", _UTF32_("\u22af") },
		{ "nVdash", _UTF32_("\u22ae") },
		{ "nabla", _UTF32_("\u2207") },
		{ "nacute", _UTF32_("\u0144") },
		{ "nacute", _UTF32_("\u006e\u0301") },
		{ "nap", _UTF32_("\u2249") },
		{ "napos", _UTF32_("\u0149") },
		{ "natur", _UTF32_("\u266e") },
		{ "nbreve", _UTF32_("\u006e\u0306") },
		{ "nbring", _UTF32_("\u006e\u032f") },
		{ "nbsp", _UTF32_("\u00a0") },
		{ "ncaron", _UTF32_("\u0148") },
		{ "ncaron", _UTF32_("\u006e\u030c") },
		{ "ncedil", _UTF32_("\u0146") },
		{ "ncirc", _UTF32_("\u006e\u0302") },
		{ "ncong", _UTF32_("\u2247") },
		{ "ncy", _UTF32_("\u043d") },
		{ "ndash", _UTF32_("\u2013") },
		{ "ndot", _UTF32_("\u006e\u0307") },
		{ "ne", _UTF32_("\u2260") },
		{ "nearr", _UTF32_("\u2197") },
		{ "nequiv", _UTF32_("\u2262") },
		{ "nexist", _UTF32_("\u2204") },
		{ "nge", _UTF32_("\u2271") },
		{ "nges", _UTF32_("\u2271") },
		{ "ngr", _UTF32_("\u03bd") },
		{ "ngrave", _UTF32_("\u006e\u0300") },
		{ "ngt", _UTF32_("\u226f") },
		{ "nhArr", _UTF32_("\u21ce") },
		{ "nharr", _UTF32_("\u21ae") },
		{ "ni", _UTF32_("\u220b") },
		{ "njcy", _UTF32_("\u045a") },
		{ "nlArr", _UTF32_("\u21cd") },
		{ "nlarr", _UTF32_("\u219a") },
		{ "nldr", _UTF32_("\u2025") },
		{ "nle", _UTF32_("\u2270") },
		{ "nles", _UTF32_("\u2270") },
		{ "nlt", _UTF32_("\u226e") },
		{ "nltri", _UTF32_("\u22ea") },
		{ "nltrie", _UTF32_("\u22ec") },
		{ "nmacr", _UTF32_("\u006e\u0304") },
		{ "nmid", _UTF32_("\u2224") },
		{ "not", _UTF32_("\u00ac") },
		{ "notin", _UTF32_("\u2209") },
		{ "npar", _UTF32_("\u2226") },
		{ "npr", _UTF32_("\u2280") },
		{ "npre", _UTF32_("\u22e0") },
		{ "nrArr", _UTF32_("\u21cf") },
		{ "nrarr", _UTF32_("\u219b") },
		{ "nrtri", _UTF32_("\u22eb") },
		{ "nrtrie", _UTF32_("\u22ed") },
		{ "nsc", _UTF32_("\u2281") },
		{ "nsce", _UTF32_("\u22e1") },
		{ "nsim", _UTF32_("\u2241") },
		{ "nsime", _UTF32_("\u2244") },
		{ "nspar", _UTF32_("\u2226") },
		{ "nsub", _UTF32_("\u2284") },
		{ "nsubE", _UTF32_("\u2288") },
		{ "nsube", _UTF32_("\u2288") },
		{ "nsup", _UTF32_("\u2285") },
		{ "nsupE", _UTF32_("\u2289") },
		{ "nsupe", _UTF32_("\u2289") },
		{ "ntilde", _UTF32_("\u00f1") },
		{ "ntilde", _UTF32_("\u006e\u0303") },
		{ "nu", _UTF32_("\u03bd") },
		{ "num", _UTF32_("\u0023") },
		{ "numero", _UTF32_("\u2116") },
		{ "numl", _UTF32_("\u006e\u0308") },
		{ "numsp", _UTF32_("\u2007") },
		{ "nvDash", _UTF32_("\u22ad") },
		{ "nvdash", _UTF32_("\u22ac") },
		{ "nwarr", _UTF32_("\u2196") },
		{ "oS", _UTF32_("\u24c8") },
		{ "oacgr", _UTF32_("\u03cc") },
		{ "oacute", _UTF32_("\u00f3") },
		{ "oacute", _UTF32_("\u006f\u0301") },
		{ "oast", _UTF32_("\u229b") },
		{ "obreve", _UTF32_("\u006f\u0306") },
		{ "obring", _UTF32_("\u006f\u032f") },
		{ "ocaron", _UTF32_("\u01d2") },
		{ "ocaron", _UTF32_("\u006f\u030c") },
		{ "ocir", _UTF32_("\u229a") },
		{ "ocirc", _UTF32_("\u00f4") },
		{ "ocirc", _UTF32_("\u006f\u0302") },
		{ "ocy", _UTF32_("\u043e") },
		{ "odash", _UTF32_("\u229d") },
		{ "odblac", _UTF32_("\u0151") },
		{ "odot", _UTF32_("\u2299") },
		{ "odot", _UTF32_("\u006f\u0307") },
		{ "odotb", _UTF32_("\u1ecd") },
		{ "oelig", _UTF32_("\u0153") },
		{ "ogon", _UTF32_("\u02db") },
		{ "ogr", _UTF32_("\u03bf") },
		{ "ograve", _UTF32_("\u00f2") },
		{ "ograve", _UTF32_("\u006f\u0300") },
		{ "ohacgr", _UTF32_("\u03ce") },
		{ "ohgr", _UTF32_("\u03c9") },
		{ "ohm", _UTF32_("\u2126") },
		{ "olarr", _UTF32_("\u21ba") },
		{ "oline", _UTF32_("\u203e") },
		{ "omacr", _UTF32_("\u014d") },
		{ "omacr", _UTF32_("\u006f\u0304") },
		{ "omega", _UTF32_("\u03c9") },
		{ "omicron", _UTF32_("\u03bf") },
		{ "ominus", _UTF32_("\u2296") },
		{ "oplus", _UTF32_("\u2295") },
		{ "or", _UTF32_("\u2228") },
		{ "orarr", _UTF32_("\u21bb") },
		{ "order", _UTF32_("\u2134") },
		{ "ordf", _UTF32_("\u00aa") },
		{ "ordm", _UTF32_("\u00ba") },
		{ "oslash", _UTF32_("\u00f8") },
		{ "osol", _UTF32_("\u2298") },
		{ "otilde", _UTF32_("\u00f5") },
		{ "otilde", _UTF32_("\u006f\u0303") },
		{ "otimes", _UTF32_("\u2297") },
		{ "ouml", _UTF32_("\u00f6") },
		{ "ouml", _UTF32_("\u006f\u0308") },
		{ "pacute", _UTF32_("\u0070\u0301") },
		{ "page", _UTF32_("\u000c") },
		{ "par", _UTF32_("\u2225") },
		{ "para", _UTF32_("\u00b6") },
		{ "part", _UTF32_("\u2202") },
		{ "pbreve", _UTF32_("\u0070\u0306") },
		{ "pbring", _UTF32_("\u0070\u032f") },
		{ "pcaron", _UTF32_("\u0070\u030c") },
		{ "pcirc", _UTF32_("\u0070\u0302") },
		{ "pcy", _UTF32_("\u043f") },
		{ "pdot", _UTF32_("\u0070\u0307") },
		{ "percnt", _UTF32_("\u0025") },
		{ "period", _UTF32_("\u002e") },
		{ "permil", _UTF32_("\u2030") },
		{ "perp", _UTF32_("\u22a5") },
		{ "pgr", _UTF32_("\u03c0") },
		{ "pgrave", _UTF32_("\u0070\u0300") },
		{ "phgr", _UTF32_("\u03c6") },
		{ "phi", _UTF32_("\u03c6") },
		{ "phis", _UTF32_("\u03c6") },
		{ "phiv", _UTF32_("\u03d5") },
		{ "phmmat", _UTF32_("\u2133") },
		{ "phone", _UTF32_("\u260e") },
		{ "pi", _UTF32_("\u03c0") },
		{ "piv", _UTF32_("\u03d6") },
		{ "planck", _UTF32_("\u210f") },
		{ "plus", _UTF32_("\u002b") },
		{ "plusb", _UTF32_("\u229e") },
		{ "plusdo", _UTF32_("\u2214") },
		{ "plusmn", _UTF32_("\u00b1") },
		{ "pmacr", _UTF32_("\u0070\u0304") },
		{ "pound", _UTF32_("\u00a3") },
		{ "pr", _UTF32_("\u227a") },
		{ "pre", _UTF32_("\u227c") },
		{ "prime", _UTF32_("\u2032") },
		{ "prnsim", _UTF32_("\u22e8") },
		{ "prod", _UTF32_("\u220f") },
		{ "prop", _UTF32_("\u221d") },
		{ "prsim", _UTF32_("\u227e") },
		{ "psgr", _UTF32_("\u03c8") },
		{ "psi", _UTF32_("\u03c8") },
		{ "ptilde", _UTF32_("\u0070\u0303") },
		{ "puml", _UTF32_("\u0070\u0308") },
		{ "puncsp", _UTF32_("\u2008") },
		{ "qacute", _UTF32_("\u0071\u0301") },
		{ "qbreve", _UTF32_("\u0071\u0306") },
		{ "qbring", _UTF32_("\u0071\u032f") },
		{ "qcaron", _UTF32_("\u0071\u030c") },
		{ "qcirc", _UTF32_("\u0071\u0302") },
		{ "qdot", _UTF32_("\u0071\u0307") },
		{ "qgrave", _UTF32_("\u0071\u0300") },
		{ "qmacr", _UTF32_("\u0071\u0304") },
		{ "qtilde", _UTF32_("\u0071\u0303") },
		{ "quest", _UTF32_("\u003f") },
		{ "quml", _UTF32_("\u0071\u0308") },
		{ "quot", _UTF32_("\u0022") },
		{ "rAarr", _UTF32_("\u21db") },
		{ "rArr", _UTF32_("\u21d2") },
		{ "racute", _UTF32_("\u0155") },
		{ "racute", _UTF32_("\u0072\u0301") },
		{ "radic", _UTF32_("\u221a") },
		{ "rang", _UTF32_("\u232a") },
		{ "raquo", _UTF32_("\u00bb") },
		{ "rarr", _UTF32_("\u2192") },
		{ "rarr2", _UTF32_("\u21c9") },
		{ "rarrhk", _UTF32_("\u21aa") },
		{ "rarrlp", _UTF32_("\u21ac") },
		{ "rarrtl", _UTF32_("\u21a3") },
		{ "rarrw", _UTF32_("\u219d") },
		{ "rbreve", _UTF32_("\u0072\u0306") },
		{ "rbring", _UTF32_("\u0072\u032f") },
		{ "rcaron", _UTF32_("\u0159") },
		{ "rcaron", _UTF32_("\u0072\u030c") },
		{ "rcedil", _UTF32_("\u0157") },
		{ "rceil", _UTF32_("\u2309") },
		{ "rcirc", _UTF32_("\u0072\u0302") },
		{ "rcub", _UTF32_("\u007d") },
		{ "rcy", _UTF32_("\u0440") },
		{ "rdot", _UTF32_("\u0072\u0307") },
		{ "rdquo", _UTF32_("\u201d") },
		{ "rdquor", _UTF32_("\u201c") },
		{ "real", _UTF32_("\u211c") },
		{ "rect", _UTF32_("\u25ad") },
		{ "reg", _UTF32_("\u00ae") },
		{ "rfloor", _UTF32_("\u230b") },
		{ "rgr", _UTF32_("\u03c1") },
		{ "rgrave", _UTF32_("\u0072\u0300") },
		{ "rhard", _UTF32_("\u21c1") },
		{ "rharu", _UTF32_("\u21c0") },
		{ "rho", _UTF32_("\u03c1") },
		{ "rhov", _UTF32_("\u03f1") },
		{ "ring", _UTF32_("\u02da") },
		{ "rlarr2", _UTF32_("\u21c4") },
		{ "rlhar2", _UTF32_("\u21cc") },
		{ "rlm", _UTF32_("\u200f") },
		{ "rmacr", _UTF32_("\u0072\u0304") },
		{ "rpar", _UTF32_("\u0029") },
		{ "rsaquo", _UTF32_("\u203a") },
		{ "rsh", _UTF32_("\u21b1") },
		{ "rsqb", _UTF32_("\u005d") },
		{ "rsquo", _UTF32_("\u2019") },
		{ "rsquor", _UTF32_("\u2018") },
		{ "rthree", _UTF32_("\u22cc") },
		{ "rtilde", _UTF32_("\u0072\u0303") },
		{ "rtimes", _UTF32_("\u22ca") },
		{ "rtri", _UTF32_("\u25b9") },
		{ "rtrie", _UTF32_("\u22b5") },
		{ "rtrif", _UTF32_("\u25b8") },
		{ "ruml", _UTF32_("\u0072\u0308") },
		{ "rx", _UTF32_("\u211e") },
		{ "sacute", _UTF32_("\u015b") },
		{ "sacute", _UTF32_("\u0073\u0301") },
		{ "samalg", _UTF32_("\u2210") },
		{ "sbquo", _UTF32_("\u201a") },
		{ "sbreve", _UTF32_("\u0073\u0306") },
		{ "sbring", _UTF32_("\u0073\u032f") },
		{ "sbsol", _UTF32_("\u005c") },
		{ "sc", _UTF32_("\u227b") },
		{ "scaron", _UTF32_("\u0161") },
		{ "scaron", _UTF32_("\u0073\u030c") },
		{ "sccue", _UTF32_("\u227d") },
		{ "sce", _UTF32_("\u227d") },
		{ "scedil", _UTF32_("\u015f") },
		{ "schwa", _UTF32_("\u0259") },
		{ "schwaacute", _UTF32_("\u0259\u0301") },
		{ "schwadgrave", _UTF32_("\u0259\u030f") },
		{ "schwagrave", _UTF32_("\u0259\u0300") },
		{ "schwamacr", _UTF32_("\u0259\u0304") },
		{ "scirc", _UTF32_("\u015d") },
		{ "scirc", _UTF32_("\u0073\u0302") },
		{ "scnsim", _UTF32_("\u22e9") },
		{ "scsim", _UTF32_("\u227f") },
		{ "scy", _UTF32_("\u0441") },
		{ "sdot", _UTF32_("\u22c5") },
		{ "sdot", _UTF32_("\u0073\u0307") },
		{ "sdotb", _UTF32_("\u22a1") },
		{ "sect", _UTF32_("\u00a7") },
		{ "semi", _UTF32_("\u003b") },
		{ "setmn", _UTF32_("\u2216") },
		{ "sext", _UTF32_("\u2736") },
		{ "sfgr", _UTF32_("\u03c2") },
		{ "sfrown", _UTF32_("\u2322") },
		{ "sgr", _UTF32_("\u03c3") },
		{ "sgrave", _UTF32_("\u0073\u0300") },
		{ "sharp", _UTF32_("\u266f") },
		{ "shchcy", _UTF32_("\u0449") },
		{ "shcy", _UTF32_("\u0448") },
		{ "shy", _UTF32_("\u00ad") },
		{ "sigma", _UTF32_("\u03c3") },
		{ "sigmaf", _UTF32_("\u03c2") },
		{ "sigmav", _UTF32_("\u03c2") },
		{ "sim", _UTF32_("\u223c") },
		{ "sime", _UTF32_("\u2243") },
		{ "smacr", _UTF32_("\u0073\u0304") },
		{ "smile", _UTF32_("\u2323") },
		{ "softcy", _UTF32_("\u044c") },
		{ "sol", _UTF32_("\u002f") },
		{ "spades", _UTF32_("\u2660") },
		{ "spar", _UTF32_("\u2225") },
		{ "sqcap", _UTF32_("\u2293") },
		{ "sqcup", _UTF32_("\u2294") },
		{ "sqsub", _UTF32_("\u228f") },
		{ "sqsube", _UTF32_("\u2291") },
		{ "sqsup", _UTF32_("\u2290") },
		{ "sqsupe", _UTF32_("\u2292") },
		{ "squ", _UTF32_("\u25a1") },
		{ "square", _UTF32_("\u25a1") },
		{ "squarf", _UTF32_("\u25a0") },
		{ "squf", _UTF32_("\u25aa") },
		{ "ssetmn", _UTF32_("\u2216") },
		{ "ssmile", _UTF32_("\u2323") },
		{ "sstarf", _UTF32_("\u22c6") },
		{ "star", _UTF32_("\u2606") },
		{ "starf", _UTF32_("\u2605") },
		{ "stilde", _UTF32_("\u0073\u0303") },
		{ "sub", _UTF32_("\u2282") },
		{ "subE", _UTF32_("\u2286") },
		{ "sube", _UTF32_("\u2286") },
		{ "subnE", _UTF32_("\u228a") },
		{ "subne", _UTF32_("\u228a") },
		{ "sum", _UTF32_("\u2211") },
		{ "suml", _UTF32_("\u0073\u0308") },
		{ "sung", _UTF32_("\u266a") },
		{ "sup", _UTF32_("\u2283") },
		{ "sup1", _UTF32_("\u00b9") },
		{ "sup2", _UTF32_("\u00b2") },
		{ "sup3", _UTF32_("\u00b3") },
		{ "supE", _UTF32_("\u2287") },
		{ "supe", _UTF32_("\u2287") },
		{ "supnE", _UTF32_("\u228b") },
		{ "supne", _UTF32_("\u228b") },
		{ "szlig", _UTF32_("\u00df") },
		{ "tacute", _UTF32_("\u0074\u0301") },
		{ "target", _UTF32_("\u2316") },
		{ "tau", _UTF32_("\u03c4") },
		{ "tbreve", _UTF32_("\u0074\u0306") },
		{ "tbring", _UTF32_("\u0074\u032f") },
		{ "tcaron", _UTF32_("\u0165") },
		{ "tcaron", _UTF32_("\u0074\u030c") },
		{ "tcedil", _UTF32_("\u0163") },
		{ "tcirc", _UTF32_("\u0074\u0302") },
		{ "tcy", _UTF32_("\u0442") },
		{ "tdot", _UTF32_("\u20db") },
		{ "tdot", _UTF32_("\u0074\u0307") },
		{ "telrec", _UTF32_("\u2315") },
		{ "tgr", _UTF32_("\u03c4") },
		{ "tgrave", _UTF32_("\u0074\u0300") },
		{ "there4", _UTF32_("\u2234") },
		{ "theta", _UTF32_("\u03b8") },
		{ "thetas", _UTF32_("\u03b8") },
		{ "thetasym", _UTF32_("\u03d1") },
		{ "thetav", _UTF32_("\u03d1") },
		{ "thgr", _UTF32_("\u03b8") },
		{ "thinsp", _UTF32_("\u2009") },
		{ "thkap", _UTF32_("\u2248") },
		{ "thksim", _UTF32_("\u223c") },
		{ "thorn", _UTF32_("\u00fe") },
		{ "tilde", _UTF32_("\u02dc") },
		{ "times", _UTF32_("\u00d7") },
		{ "timesb", _UTF32_("\u22a0") },
		{ "tmacr", _UTF32_("\u0074\u0304") },
		{ "top", _UTF32_("\u22a4") },
		{ "tprime", _UTF32_("\u2034") },
		{ "trade", _UTF32_("\u2122") },
		{ "trie", _UTF32_("\u225c") },
		{ "tscy", _UTF32_("\u0446") },
		{ "tshcy", _UTF32_("\u045b") },
		{ "tstrok", _UTF32_("\u0167") },
		{ "ttilde", _UTF32_("\u0074\u0303") },
		{ "tuml", _UTF32_("\u0074\u0308") },
		{ "twixt", _UTF32_("\u226c") },
		{ "uArr", _UTF32_("\u21d1") },
		{ "uacgr", _UTF32_("\u03cd") },
		{ "uacute", _UTF32_("\u00fa") },
		{ "uacute", _UTF32_("\u0075\u0301") },
		{ "uarr", _UTF32_("\u2191") },
		{ "uarr2", _UTF32_("\u21c8") },
		{ "ubrcy", _UTF32_("\u045e") },
		{ "ubreve", _UTF32_("\u016d") },
		{ "ubreve", _UTF32_("\u0075\u0306") },
		{ "ubring", _UTF32_("\u0075\u032f") },
		{ "ucaron", _UTF32_("\u0075\u030c") },
		{ "ucirc", _UTF32_("\u00fb") },
		{ "ucirc", _UTF32_("\u0075\u0302") },
		{ "ucy", _UTF32_("\u0443") },
		{ "udblac", _UTF32_("\u0171") },
		{ "udiagr", _UTF32_("\u03b0") },
		{ "udigr", _UTF32_("\u03cb") },
		{ "udot", _UTF32_("\u0075\u0307") },
		{ "ugr", _UTF32_("\u03c5") },
		{ "ugrave", _UTF32_("\u00f9") },
		{ "ugrave", _UTF32_("\u0075\u0300") },
		{ "uharl", _UTF32_("\u21bf") },
		{ "uharr", _UTF32_("\u21be") },
		{ "uhblk", _UTF32_("\u2580") },
		{ "ulcorn", _UTF32_("\u231c") },
		{ "ulcrop", _UTF32_("\u230f") },
		{ "umacr", _UTF32_("\u016b") },
		{ "umacr", _UTF32_("\u0075\u0304") },
		{ "uml", _UTF32_("\u00a8") },
		{ "uogon", _UTF32_("\u0173") },
		{ "uplus", _UTF32_("\u228e") },
		{ "upsi", _UTF32_("\u03c5") },
		{ "upsih", _UTF32_("\u03d2") },
		{ "upsilon", _UTF32_("\u03c5") },
		{ "urcorn", _UTF32_("\u231d") },
		{ "urcrop", _UTF32_("\u230e") },
		{ "uring", _UTF32_("\u016f") },
		{ "utilde", _UTF32_("\u0169") },
		{ "utilde", _UTF32_("\u0075\u0303") },
		{ "utri", _UTF32_("\u25b5") },
		{ "utrif", _UTF32_("\u25b4") },
		{ "uuml", _UTF32_("\u00fc") },
		{ "uuml", _UTF32_("\u0075\u0308") },
		{ "vArr", _UTF32_("\u21d5") },
		{ "vDash", _UTF32_("\u22a8") },
		{ "vacute", _UTF32_("\u0076\u0301") },
		{ "varr", _UTF32_("\u2195") },
		{ "vbreve", _UTF32_("\u0076\u0306") },
		{ "vbring", _UTF32_("\u0076\u032f") },
		{ "vcaron", _UTF32_("\u0076\u030c") },
		{ "vcirc", _UTF32_("\u0076\u0302") },
		{ "vcy", _UTF32_("\u0432") },
		{ "vdash", _UTF32_("\u22a2") },
		{ "vdot", _UTF32_("\u0076\u0307") },
		{ "veebar", _UTF32_("\u22bb") },
		{ "vellip", _UTF32_("\u22ee") },
		{ "verbar", _UTF32_("\u007c") },
		{ "vgrave", _UTF32_("\u0076\u0300") },
		{ "vltri", _UTF32_("\u22b2") },
		{ "vmacr", _UTF32_("\u0076\u0304") },
		{ "vprime", _UTF32_("\u2032") },
		{ "vprop", _UTF32_("\u221d") },
		{ "vrtri", _UTF32_("\u22b3") },
		{ "vsubnE", _UTF32_("\u228a") },
		{ "vsubne", _UTF32_("\u228a") },
		{ "vsupnE", _UTF32_("\u228b") },
		{ "vsupne", _UTF32_("\u228b") },
		{ "vtab", _UTF32_("\u000b") },
		{ "vtilde", _UTF32_("\u0076\u0303") },
		{ "vuml", _UTF32_("\u0076\u0308") },
		{ "wacute", _UTF32_("\u0077\u0301") },
		{ "wbreve", _UTF32_("\u0077\u0306") },
		{ "wbring", _UTF32_("\u0077\u032f") },
		{ "wcaron", _UTF32_("\u0077\u030c") },
		{ "wcirc", _UTF32_("\u0175") },
		{ "wcirc", _UTF32_("\u0077\u0302") },
		{ "wdot", _UTF32_("\u0077\u0307") },
		{ "wedgeq", _UTF32_("\u2259") },
		{ "weierp", _UTF32_("\u2118") },
		{ "wgrave", _UTF32_("\u0077\u0300") },
		{ "wmacr", _UTF32_("\u0077\u0304") },
		{ "wreath", _UTF32_("\u2240") },
		{ "wtilde", _UTF32_("\u0077\u0303") },
		{ "wuml", _UTF32_("\u0077\u0308") },
		{ "xacute", _UTF32_("\u0078\u0301") },
		{ "xbreve", _UTF32_("\u0078\u0306") },
		{ "xbring", _UTF32_("\u0078\u032f") },
		{ "xcaron", _UTF32_("\u0078\u030c") },
		{ "xcirc", _UTF32_("\u25cb") },
		{ "xcirc", _UTF32_("\u0078\u0302") },
		{ "xdot", _UTF32_("\u0078\u0307") },
		{ "xdtri", _UTF32_("\u25bd") },
		{ "xgr", _UTF32_("\u03be") },
		{ "xgrave", _UTF32_("\u0078\u0300") },
		{ "xhArr", _UTF32_("\u2194") },
		{ "xharr", _UTF32_("\u2194") },
		{ "xi", _UTF32_("\u03be") },
		{ "xlArr", _UTF32_("\u21d0") },
		{ "xmacr", _UTF32_("\u0078\u0304") },
		{ "xrArr", _UTF32_("\u21d2") },
		{ "xtilde", _UTF32_("\u0078\u0303") },
		{ "xuml", _UTF32_("\u0078\u0308") },
		{ "xutri", _UTF32_("\u25b3") },
		{ "yacute", _UTF32_("\u00fd") },
		{ "yacute", _UTF32_("\u0079\u0301") },
		{ "yacy", _UTF32_("\u044f") },
		{ "ybreve", _UTF32_("\u0079\u0306") },
		{ "ybring", _UTF32_("\u0079\u032f") },
		{ "ycaron", _UTF32_("\u0079\u030c") },
		{ "ycirc", _UTF32_("\u0177") },
		{ "ycirc", _UTF32_("\u0079\u0302") },
		{ "ycy", _UTF32_("\u044b") },
		{ "ydot", _UTF32_("\u0079\u0307") },
		{ "yen", _UTF32_("\u00a5") },
		{ "ygrave", _UTF32_("\u0079\u0300") },
		{ "yicy", _UTF32_("\u0457") },
		{ "ymacr", _UTF32_("\u0079\u0304") },
		{ "ytilde", _UTF32_("\u0079\u0303") },
		{ "yucy", _UTF32_("\u044e") },
		{ "yuml", _UTF32_("\u00ff") },
		{ "yuml", _UTF32_("\u0079\u0308") },
		{ "zacute", _UTF32_("\u017a") },
		{ "zacute", _UTF32_("\u007a\u0301") },
		{ "zbreve", _UTF32_("\u007a\u0306") },
		{ "zbring", _UTF32_("\u007a\u032f") },
		{ "zcaron", _UTF32_("\u017e") },
		{ "zcaron", _UTF32_("\u007a\u030c") },
		{ "zcirc", _UTF32_("\u007a\u0302") },
		{ "zcy", _UTF32_("\u0437") },
		{ "zdot", _UTF32_("\u017c") },
		{ "zdot", _UTF32_("\u007a\u0307") },
		{ "zeta", _UTF32_("\u03b6") },
		{ "zgr", _UTF32_("\u03b6") },
		{ "zgrave", _UTF32_("\u007a\u0300") },
		{ "zhcy", _UTF32_("\u0436") },
		{ "zmacr", _UTF32_("\u007a\u0304") },
		{ "ztilde", _UTF32_("\u007a\u0303") },
		{ "zuml", _UTF32_("\u007a\u0308") },
		{ "zwj", _UTF32_("\u200d") },
		{ "zwnj", _UTF32_("\u200c") },
	};

	inline const size_t unicode_sgml[] = {
		0x5b6,
		0x48d,
		0x30d,
		0x4c3,
		0x457,
		0x2d2,
		0x497,
		0x1f1,
		0x1fb,
		0x3e6,
		0x4ec,
		0x1fe,
		0x4a6,
		0x29b,
		0x36e,
		0x498,
		0x528,
		0x299,
		0x515,
		0x3f1,
		0x303,
		0x353,
		0x4c1,
		0x29c,
		0xe,
		0x3,
		0x9,
		0x15,
		0x11,
		0x5,
		0xb,
		0x17,
		0x7,
		0x6,
		0x22,
		0x18,
		0x1d,
		0x24,
		0x23,
		0x1a,
		0x1f,
		0x25,
		0x1c,
		0x1b,
		0x33,
		0x28,
		0x30,
		0x36,
		0x35,
		0x2a,
		0x32,
		0x37,
		0x2d,
		0x2b,
		0x47,
		0x3c,
		0x42,
		0x4c,
		0x48,
		0x3e,
		0x44,
		0x4d,
		0x41,
		0x3f,
		0x61,
		0x54,
		0x5a,
		0x67,
		0x63,
		0x55,
		0x5d,
		0x69,
		0x58,
		0x56,
		0x71,
		0x6a,
		0x6e,
		0x73,
		0x72,
		0x6b,
		0x70,
		0x74,
		0x6d,
		0x6c,
		0x84,
		0x76,
		0x7e,
		0x87,
		0x85,
		0x79,
		0x81,
		0x88,
		0x7b,
		0x7a,
		0x91,
		0x8a,
		0x8f,
		0x94,
		0x92,
		0x8b,
		0x90,
		0x95,
		0x8d,
		0x8c,
		0xa7,
		0x9b,
		0xa0,
		0xad,
		0xa9,
		0x9c,
		0xa4,
		0xb0,
		0x9e,
		0x9d,
		0xb9,
		0xb1,
		0xb6,
		0xbc,
		0xba,
		0xb2,
		0xb8,
		0xbe,
		0xb4,
		0xb3,
		0xcc,
		0xc2,
		0xc8,
		0xce,
		0xcd,
		0xc4,
		0xca,
		0xcf,
		0xc6,
		0xc5,
		0xde,
		0xd2,
		0xda,
		0xe4,
		0xe0,
		0xd5,
		0xdc,
		0xe5,
		0xd8,
		0xd6,
		0xee,
		0xe6,
		0xea,
		0xf0,
		0xef,
		0xe7,
		0xec,
		0xf2,
		0xe9,
		0xe8,
		0xff,
		0xf5,
		0xfb,
		0x102,
		0x100,
		0xf6,
		0xfd,
		0x104,
		0xf9,
		0xf7,
		0x117,
		0x10a,
		0x110,
		0x11e,
		0x119,
		0x10b,
		0x113,
		0x120,
		0x10e,
		0x10c,
		0x12b,
		0x123,
		0x127,
		0x131,
		0x12e,
		0x124,
		0x129,
		0x132,
		0x126,
		0x125,
		0x139,
		0x133,
		0x137,
		0x13b,
		0x13a,
		0x134,
		0x138,
		0x13c,
		0x136,
		0x135,
		0x149,
		0x13e,
		0x145,
		0x14c,
		0x14b,
		0x140,
		0x147,
		0x14d,
		0x143,
		0x141,
		0x15d,
		0x152,
		0x159,
		0x160,
		0x15f,
		0x153,
		0x15b,
		0x162,
		0x156,
		0x154,
		0x173,
		0x168,
		0x16f,
		0x177,
		0x175,
		0x16a,
		0x171,
		0x178,
		0x16d,
		0x16b,
		0x189,
		0x17b,
		0x182,
		0x191,
		0x18b,
		0x17e,
		0x186,
		0x193,
		0x180,
		0x17f,
		0x19d,
		0x194,
		0x198,
		0x19f,
		0x19e,
		0x195,
		0x19b,
		0x1a0,
		0x197,
		0x196,
		0x1a9,
		0x1a2,
		0x1a7,
		0x1ab,
		0x1aa,
		0x1a3,
		0x1a8,
		0x1ac,
		0x1a5,
		0x1a4,
		0x1b4,
		0x1ad,
		0x1b1,
		0x1b7,
		0x1b6,
		0x1ae,
		0x1b2,
		0x1b8,
		0x1b0,
		0x1af,
		0x1c5,
		0x1bd,
		0x1c2,
		0x1c7,
		0x1c6,
		0x1be,
		0x1c4,
		0x1c9,
		0x1c0,
		0x1bf,
		0x1d7,
		0x1cc,
		0x1d1,
		0x1d9,
		0x1d8,
		0x1cd,
		0x1d4,
		0x1da,
		0x1d0,
		0x1ce,
		0x3ed,
		0x275,
		0x500,
		0x4ef,
		0x3e2,
		0x350,
		0x1ea,
		0x1dd,
		0x1e3,
		0x201,
		0x1ef,
		0x1df,
		0x1e6,
		0x203,
		0x1e1,
		0x1e0,
		0x23f,
		0x22f,
		0x234,
		0x276,
		0x245,
		0x231,
		0x237,
		0x278,
		0x233,
		0x232,
		0x28b,
		0x27c,
		0x286,
		0x2a6,
		0x298,
		0x280,
		0x288,
		0x2aa,
		0x283,
		0x281,
		0x2c4,
		0x2b2,
		0x2be,
		0x2d9,
		0x2d1,
		0x2ba,
		0x2c0,
		0x2dc,
		0x2bd,
		0x2bb,
		0x2f3,
		0x2e1,
		0x2e8,
		0x309,
		0x2f8,
		0x2e2,
		0x2ec,
		0x30b,
		0x2e5,
		0x2e3,
		0x31a,
		0x30f,
		0x313,
		0x333,
		0x31e,
		0x310,
		0x315,
		0x334,
		0x312,
		0x311,
		0x348,
		0x337,
		0x340,
		0x354,
		0x34c,
		0x33b,
		0x343,
		0x355,
		0x33d,
		0x33c,
		0x367,
		0x358,
		0x363,
		0x36b,
		0x368,
		0x35f,
		0x364,
		0x36c,
		0x361,
		0x360,
		0x380,
		0x371,
		0x376,
		0x391,
		0x383,
		0x372,
		0x37a,
		0x394,
		0x374,
		0x373,
		0x39d,
		0x395,
		0x39a,
		0x3a0,
		0x39e,
		0x396,
		0x39c,
		0x3a2,
		0x398,
		0x397,
		0x3ae,
		0x3a3,
		0x3aa,
		0x3b4,
		0x3b3,
		0x3a6,
		0x3ac,
		0x3b5,
		0x3a8,
		0x3a7,
		0x3d7,
		0x3ba,
		0x3ca,
		0x3f3,
		0x3dc,
		0x3c4,
		0x3ce,
		0x3f8,
		0x3c7,
		0x3c5,
		0x408,
		0x3fb,
		0x403,
		0x412,
		0x40f,
		0x400,
		0x406,
		0x415,
		0x402,
		0x401,
		0x430,
		0x41a,
		0x424,
		0x455,
		0x43e,
		0x41e,
		0x428,
		0x459,
		0x422,
		0x41f,
		0x474,
		0x461,
		0x469,
		0x488,
		0x47b,
		0x463,
		0x46e,
		0x48b,
		0x466,
		0x464,
		0x49c,
		0x48c,
		0x494,
		0x4b5,
		0x4aa,
		0x491,
		0x496,
		0x4b6,
		0x493,
		0x492,
		0x4be,
		0x4b8,
		0x4bc,
		0x4c0,
		0x4bf,
		0x4b9,
		0x4bd,
		0x4c2,
		0x4bb,
		0x4ba,
		0x4e2,
		0x4c7,
		0x4d7,
		0x4f3,
		0x4eb,
		0x4d1,
		0x4da,
		0x4f8,
		0x4d4,
		0x4d2,
		0x51b,
		0x4fb,
		0x50d,
		0x53a,
		0x525,
		0x4fe,
		0x512,
		0x541,
		0x503,
		0x4ff,
		0x55a,
		0x54c,
		0x554,
		0x570,
		0x568,
		0x54f,
		0x557,
		0x571,
		0x552,
		0x550,
		0x587,
		0x576,
		0x57f,
		0x599,
		0x58e,
		0x57b,
		0x584,
		0x59d,
		0x57d,
		0x57c,
		0x5ac,
		0x5a0,
		0x5a5,
		0x5b7,
		0x5ae,
		0x5a2,
		0x5a8,
		0x5b8,
		0x5a4,
		0x5a3,
		0x5c2,
		0x5b9,
		0x5be,
		0x5c5,
		0x5c3,
		0x5ba,
		0x5bf,
		0x5c6,
		0x5bc,
		0x5bb,
		0x5d0,
		0x5c7,
		0x5cc,
		0x5d7,
		0x5d5,
		0x5c8,
		0x5cd,
		0x5d8,
		0x5ca,
		0x5c9,
		0x5e5,
		0x5db,
		0x5e1,
		0x5e8,
		0x5e7,
		0x5dd,
		0x5e3,
		0x5eb,
		0x5df,
		0x5de,
		0x5f8,
		0x5ed,
		0x5f2,
		0x5fb,
		0x5fa,
		0x5ee,
		0x5f5,
		0x5fc,
		0x5f1,
		0x5ef,
		0x3cb,
		0x5ab,
		0x4d8,
		0x420,
		0x37c,
		0x28a,
		0x4ab,
		0x2ae,
		0x5e4,
		0x272,
		0x514,
		0x49,
		0x2ca,
		0x58f,
		0x2a2,
		0x483,
		0x3be,
		0x440,
		0x51f,
		0x4df,
		0x3fa,
		0x2c1,
		0x4a9,
		0x545,
		0x546,
		0x1e4,
		0x409,
		0x48f,
		0x40b,
		0x289,
		0x544,
		0x484,
		0x4ca,
		0x324,
		0x322,
		0x35a,
		0x32a,
		0x38e,
		0xd,
		0x2,
		0x8,
		0x14,
		0x16,
		0x13,
		0x0,
		0x2e,
		0x60,
		0x53,
		0x59,
		0x68,
		0xa6,
		0x9a,
		0x9f,
		0xaf,
		0x51,
		0x101,
		0x116,
		0x109,
		0x10f,
		0x11d,
		0x11f,
		0x566,
		0x11c,
		0x188,
		0x17a,
		0x181,
		0x192,
		0x1bc,
		0x164,
		0x54b,
		0x1e9,
		0x1dc,
		0x1e2,
		0x200,
		0x202,
		0x1fd,
		0x1e7,
		0x284,
		0x2f2,
		0x2e0,
		0x2e7,
		0x30a,
		0x37f,
		0x370,
		0x375,
		0x393,
		0x308,
		0x454,
		0x473,
		0x460,
		0x468,
		0x487,
		0x48a,
		0x2cb,
		0x485,
		0x586,
		0x575,
		0x57e,
		0x59c,
		0x5da,
		0x564,
		0x5ea,
		0x10,
		0x1ee,
		0x4,
		0x1de,
		0x12,
		0x1f8,
		0x27,
		0x27b,
		0x2f,
		0x285,
		0x31,
		0x287,
		0x2c,
		0x282,
		0x40,
		0x2bc,
		0x4b,
		0x2d8,
		0x62,
		0x2f7,
		0x5c,
		0x2eb,
		0x64,
		0x2ff,
		0x57,
		0x2e4,
		0x7d,
		0x33f,
		0x78,
		0x33a,
		0x80,
		0x342,
		0x7c,
		0x33e,
		0x8e,
		0x362,
		0x93,
		0x36a,
		0xac,
		0x390,
		0xa8,
		0x382,
		0xaa,
		0x38c,
		0xa3,
		0x387,
		0x388,
		0x97,
		0x381,
		0xb5,
		0x399,
		0xc7,
		0x3a9,
		0x3af,
		0xd1,
		0x3b9,
		0xd9,
		0x3c8,
		0xd7,
		0x3c6,
		0xe1,
		0x3dd,
		0xe2,
		0x3f0,
		0xf4,
		0x419,
		0xfa,
		0x423,
		0xf8,
		0x421,
		0x41c,
		0x50,
		0x2fd,
		0x118,
		0x47a,
		0x112,
		0x46c,
		0x105,
		0x470,
		0x13d,
		0x4c6,
		0x144,
		0x4d5,
		0x142,
		0x4d3,
		0x151,
		0x4fa,
		0x158,
		0x50c,
		0x157,
		0x506,
		0x155,
		0x502,
		0x16e,
		0x553,
		0x16c,
		0x551,
		0x176,
		0x56f,
		0x190,
		0x598,
		0x18a,
		0x58d,
		0x17d,
		0x57a,
		0x18f,
		0x597,
		0x184,
		0x581,
		0x18c,
		0x590,
		0x1a6,
		0x5bd,
		0x1c1,
		0x5e0,
		0x1c8,
		0x1cb,
		0x5ec,
		0x1d3,
		0x5f4,
		0x1cf,
		0x5f0,
		0x31f,
		0x10d,
		0x465,
		0x336,
		0x507,
		0x50a,
		0x508,
		0x50b,
		0x509,
		0x1fc,
		0x290,
		0x27f,
		0x271,
		0x2d3,
		0x4e7,
		0x471,
		0x565,
		0x2b9,
		0x1,
		0x52,
		0x4e,
		0x99,
		0x108,
		0x179,
		0x106,
		0x378,
		0xc,
		0xf,
		0x20,
		0x21,
		0x77,
		0x83,
		0x205,
		0x45,
		0x46,
		0x204,
		0x5f,
		0x65,
		0x1d5,
		0x1d6,
		0x4f,
		0x66,
		0x165,
		0x174,
		0x20c,
		0xa5,
		0xab,
		0xc3,
		0xcb,
		0xd3,
		0xdd,
		0x206,
		0xed,
		0xf1,
		0xfe,
		0x103,
		0x1b3,
		0x1b5,
		0x20e,
		0x115,
		0x11b,
		0x12a,
		0x12d,
		0x209,
		0x148,
		0x14a,
		0x15c,
		0x15e,
		0x20b,
		0x169,
		0x172,
		0x187,
		0x18d,
		0x18e,
		0x20d,
		0x121,
		0x12c,
		0x208,
		0x34,
		0xc0,
		0x122,
		0x130,
		0x20a,
		0x107,
		0x11a,
		0x207,
		0xa2,
		0x185,
		0x1db,
		0x2df,
		0x2ee,
		0x36f,
		0x582,
		0x1e8,
		0x1ed,
		0x20f,
		0x210,
		0x23c,
		0x23e,
		0x217,
		0x338,
		0x347,
		0x212,
		0x2c2,
		0x2c3,
		0x213,
		0x214,
		0x215,
		0x2f1,
		0x300,
		0x301,
		0x22e,
		0x5f6,
		0x5f7,
		0x216,
		0x2ef,
		0x307,
		0x22a,
		0x55c,
		0x55d,
		0x560,
		0x219,
		0x37e,
		0x38d,
		0x21a,
		0x3a4,
		0x3ad,
		0x21c,
		0x3bc,
		0x3d6,
		0x21d,
		0x407,
		0x413,
		0x21e,
		0x42f,
		0x456,
		0x22d,
		0x5cf,
		0x5d3,
		0x472,
		0x47d,
		0x222,
		0x49b,
		0x4a3,
		0x225,
		0x4e1,
		0x4e5,
		0x228,
		0x518,
		0x521,
		0x522,
		0x227,
		0x51a,
		0x520,
		0x229,
		0x54e,
		0x559,
		0x22c,
		0x585,
		0x592,
		0x594,
		0x220,
		0x49d,
		0x49e,
		0x49f,
		0x211,
		0x28e,
		0x3b1,
		0x224,
		0x4b3,
		0x4b4,
		0x476,
		0x47c,
		0x379,
		0x583,
		0x45f,
		0x574,
		0x21f,
		0x475,
		0x22b,
		0x55e,
		0x55f,
		0x593,
		0x221,
		0x4a0,
		0x223,
		0x4a4,
		0x218,
		0x339,
		0x21b,
		0x3a5,
		0x226,
		0x4e6,
		0x98,
		0x39,
		0x75,
		0xbd,
		0x3a,
		0xae,
		0x1ba,
		0xbb,
		0xd0,
		0xf3,
		0x166,
		0xc1,
		0x17c,
		0x3b,
		0xa,
		0x1e,
		0x199,
		0x7f,
		0x43,
		0x96,
		0x1ca,
		0x1d2,
		0xa1,
		0xb7,
		0xc9,
		0xdb,
		0xeb,
		0xfc,
		0x111,
		0x128,
		0x146,
		0x15a,
		0x170,
		0x183,
		0x6f,
		0xbf,
		0x167,
		0x26,
		0x14f,
		0x14e,
		0x89,
		0x1c3,
		0x150,
		0x5b,
		0x1bb,
		0x1b9,
		0x1e5,
		0x236,
		0x5a6,
		0x341,
		0x2bf,
		0x37b,
		0x5f9,
		0x5f3,
		0x377,
		0x39b,
		0x3ab,
		0x3cc,
		0x404,
		0x426,
		0x46a,
		0x495,
		0x4d9,
		0x510,
		0x555,
		0x580,
		0x314,
		0x3b0,
		0x56d,
		0x28c,
		0x51e,
		0x51d,
		0x35c,
		0x5e2,
		0x527,
		0x2ea,
		0x5e9,
		0x5dc,
		0x38b,
		0x2cd,
		0x34a,
		0x3a1,
		0x2d7,
		0x392,
		0x5e6,
		0x39f,
		0x3db,
		0x435,
		0x56e,
		0x3b2,
		0x579,
		0x2dd,
		0x5e,
		0x2ed,
		0x114,
		0x46f,
		0x2fe,
		0x2fa,
		0x2fb,
		0x2fc,
		0x45a,
		0x4b7,
		0x561,
		0x359,
		0x5fe,
		0x5fd,
		0x3e9,
		0x4ea,
		0x2b7,
		0x427,
		0x405,
		0x369,
		0x19c,
		0x3ee,
		0x4f1,
		0x4f0,
		0x3ef,
		0x4fd,
		0x3cf,
		0x4dc,
		0x4db,
		0x238,
		0x3d0,
		0x2b3,
		0x3d,
		0x277,
		0x438,
		0x366,
		0x40e,
		0x499,
		0x4ae,
		0x5af,
		0x12f,
		0x56a,
		0x270,
		0x3ea,
		0x4ed,
		0x479,
		0x27e,
		0x36d,
		0x331,
		0x30c,
		0x556,
		0x4a,
		0x385,
		0x35b,
		0x4a5,
		0x384,
		0x3bb,
		0x2f5,
		0x458,
		0x2a3,
		0x5c1,
		0x4dd,
		0x4f9,
		0x56b,
		0x477,
		0x1f7,
		0x23b,
		0x4a1,
		0x482,
		0x1eb,
		0x1ec,
		0x23d,
		0x349,
		0x2b4,
		0x323,
		0x328,
		0x325,
		0x329,
		0x32b,
		0x32d,
		0x326,
		0x32e,
		0x327,
		0x32c,
		0x32f,
		0x330,
		0x3bf,
		0x577,
		0x4cb,
		0x2b5,
		0x35d,
		0x5d1,
		0x5d2,
		0x5a1,
		0x45d,
		0x42a,
		0x2d4,
		0x2ce,
		0x437,
		0x446,
		0x4d0,
		0xd4,
		0x13f,
		0x3c3,
		0x4cf,
		0x3fe,
		0x3c1,
		0x4cd,
		0x3c2,
		0x4ce,
		0x35e,
		0x433,
		0x3eb,
		0x4ee,
		0x2a4,
		0x2a9,
		0x2ad,
		0x478,
		0x481,
		0x3d9,
		0x3d8,
		0x589,
		0x588,
		0x4e4,
		0x4e3,
		0x2c6,
		0x2c5,
		0x4e8,
		0x3e7,
		0x3c0,
		0x578,
		0x4cc,
		0x2b6,
		0x3e8,
		0x4e9,
		0x436,
		0x432,
		0x445,
		0x3b7,
		0x5d4,
		0x573,
		0x4c5,
		0x5d6,
		0x2b1,
		0x357,
		0x37d,
		0x59e,
		0x3b6,
		0x4c4,
		0x320,
		0x29d,
		0x490,
		0x30e,
		0x42c,
		0x2f9,
		0x418,
		0x38f,
		0x441,
		0x302,
		0x434,
		0x23a,
		0x4b0,
		0x1f0,
		0x2a1,
		0x4fc,
		0x540,
		0x40c,
		0x410,
		0x4a8,
		0x516,
		0x535,
		0x3e1,
		0x29e,
		0x4c8,
		0x4b1,
		0x5b0,
		0x386,
		0x1f4,
		0x1f3,
		0x1f5,
		0x1f6,
		0x40a,
		0x43f,
		0x48e,
		0x52a,
		0x442,
		0x44d,
		0x1f2,
		0x480,
		0x27d,
		0x2ab,
		0x389,
		0x2a0,
		0x55b,
		0x239,
		0x523,
		0x563,
		0x273,
		0x5c4,
		0x44b,
		0x524,
		0x44c,
		0x29f,
		0x425,
		0x1f9,
		0x1ff,
		0x562,
		0x41b,
		0x1fa,
		0x235,
		0x279,
		0x27a,
		0x306,
		0x2de,
		0x2f0,
		0x305,
		0x29a,
		0x2e9,
		0x2e6,
		0x296,
		0x5c0,
		0x56c,
		0x429,
		0x304,
		0x42b,
		0x3d1,
		0x3d3,
		0x344,
		0x346,
		0x3b8,
		0x335,
		0x3de,
		0x3df,
		0x3f9,
		0x34d,
		0x34e,
		0x356,
		0xe3,
		0x86,
		0x572,
		0x43b,
		0x431,
		0x439,
		0x43a,
		0x42d,
		0x42e,
		0x3ec,
		0x352,
		0x3d5,
		0x34b,
		0x4ac,
		0x501,
		0x2ac,
		0x4ad,
		0x504,
		0x505,
		0x4b2,
		0x50f,
		0x443,
		0x449,
		0x53b,
		0x543,
		0x44e,
		0x451,
		0x53c,
		0x53d,
		0x547,
		0x548,
		0x44f,
		0x450,
		0x452,
		0x453,
		0x53e,
		0x53f,
		0x5b2,
		0x5b3,
		0x549,
		0x54a,
		0x5b4,
		0x5b5,
		0x591,
		0x52d,
		0x52f,
		0x52e,
		0x530,
		0x52b,
		0x52c,
		0x47f,
		0x47e,
		0x489,
		0x486,
		0x46d,
		0x467,
		0x462,
		0x46b,
		0x4a7,
		0x40d,
		0x567,
		0x513,
		0x5a7,
		0x2b8,
		0x569,
		0x246,
		0x49a,
		0x411,
		0x59f,
		0x19a,
		0x1a1,
		0x45c,
		0x45b,
		0x417,
		0x416,
		0x5ad,
		0x5b1,
		0x3f6,
		0x4f6,
		0x414,
		0x38a,
		0x5a9,
		0x230,
		0x2c7,
		0x511,
		0x537,
		0x2cc,
		0x247,
		0x3f4,
		0x4f4,
		0x3f2,
		0x4f2,
		0x274,
		0x2af,
		0x2b0,
		0x161,
		0x163,
		0x29,
		0x38,
		0x321,
		0x3cd,
		0x351,
		0xdf,
		0x82,
		0x3d2,
		0x345,
		0x2f6,
		0x2f4,
		0x2a7,
		0x2a8,
		0x444,
		0x44a,
		0x3e0,
		0x34f,
		0x4af,
		0x50e,
		0x43c,
		0x447,
		0x43d,
		0x448,
		0x5aa,
		0x19,
		0x3c9,
		0x4d6,
		0x3d4,
		0x4e0,
		0x2d6,
		0x2d0,
		0x596,
		0x58c,
		0x558,
		0x54d,
		0x58b,
		0x595,
		0x2cf,
		0x2d5,
		0x332,
		0x519,
		0x526,
		0x536,
		0x3bd,
		0x4c9,
		0x240,
		0x45e,
		0x260,
		0x269,
		0x25f,
		0x25e,
		0x268,
		0x267,
		0x26f,
		0x26e,
		0x263,
		0x264,
		0x26d,
		0x24c,
		0x255,
		0x25d,
		0x24b,
		0x249,
		0x25c,
		0x24a,
		0x248,
		0x266,
		0x254,
		0x252,
		0x265,
		0x253,
		0x251,
		0x26c,
		0x25b,
		0x258,
		0x26b,
		0x25a,
		0x257,
		0x24f,
		0x261,
		0x24d,
		0x250,
		0x262,
		0x24e,
		0x26a,
		0x259,
		0x256,
		0x58a,
		0x3da,
		0x244,
		0x242,
		0x241,
		0x243,
		0x533,
		0x531,
		0x532,
		0x534,
		0x4de,
		0x3ff,
		0x5d9,
		0x59b,
		0x59a,
		0x4f7,
		0x4f5,
		0x5ce,
		0x2db,
		0x2da,
		0x3f7,
		0x3f5,
		0x2c8,
		0x3e3,
		0x28f,
		0x5cb,
		0x291,
		0x293,
		0x294,
		0x292,
		0x295,
		0x539,
		0x538,
		0x4a2,
		0x316,
		0x3fc,
		0x529,
		0x297,
		0x365,
		0x2c9,
		0x542,
		0x31c,
		0x41d,
		0x51c,
		0x28d,
		0x2a5,
		0x3fd,
		0x3e5,
		0x3e4,
		0x517,
		0x318,
		0x31b,
		0x31d,
		0x317,
		0x319,
	};
	/// \endcond
}

#undef __UTF32_
#undef _UTF32_
